@@ -39,7 +39,7 @@ char PlugIn_Info[] = "nice D.O.S.  BE CAREFULL !!";
 short PlugIn_Version = 8;
 
 
-#define SYN_SEQ 6969
+#define SYN_SEQ 0xabadc0de
 
 // global data...
 
@@ -189,7 +189,7 @@ void PlugIn_Start(char**argv)
             Inet_Forge_ip( pck_to_send + ETH_HEADER, IPS, IPD, TCP_HEADER, IP_ID++, 0, IPPROTO_TCP);
             Inet_Forge_tcp( pck_to_send + ETH_HEADER + IP_HEADER, PORTS, i,  SYN_SEQ, 0, TH_SYN, 0, 0);
             Inet_SendRawPacket(sock, pck_to_send, ETH_HEADER + IP_HEADER + TCP_HEADER );
-	    if(!(i%5)) usleep(500);
+	    		if(!(i%5)) usleep(500);
          }
 
          recv_pck = (char *)Inet_Forge_packet(MTU);
@@ -230,8 +230,10 @@ void PlugIn_Start(char**argv)
                Inet_Forge_tcp( pck_to_send + ETH_HEADER + IP_HEADER, PORTS, PORTREP[index],  SYN_SEQ, 0, TH_SYN, 0, 0);
                Inet_SendRawPacket(sock, pck_to_send, ETH_HEADER + IP_HEADER + TCP_HEADER );
                if (!(index%5)) usleep(500);
-	    }
-	    usleep(2000);
+	    		}
+
+	    		usleep(2000);
+
             if (Plugin_Input(c, 1, P_NONBLOCK))
             {
                kill(CID1,SIGTERM);
