@@ -1,5 +1,5 @@
 /*
-    ettercap -- dissector FTP
+    ettercap -- dissector FTP -- TCP 21
 
     Copyright (C) 2001  ALoR <alor@users.sourceforge.net>, NaGA <crwm@freemail.it>
 
@@ -45,8 +45,6 @@ FUNC_DISSECTOR(Dissector_ftp)
 
    TCP_header *tcp;
    u_char *payload;
-   char *fromhere;
-
    ONLY_CONNECTION;
 
    tcp = (TCP_header *) data;
@@ -55,26 +53,25 @@ FUNC_DISSECTOR(Dissector_ftp)
 
    payload = (char *)((int)tcp + tcp->doff * 4);
 
-   if ((fromhere = strstr(payload, "USER")) || (fromhere = strstr(payload, "user")))
+   if ( !strncasecmp(payload, "USER", 4) )
    {
       char user[25];
-      strncpy(user, fromhere + strlen("USER ") , 25 );
 
-      strcat(data_to_ettercap->user, user);
       #ifdef DEBUG
          Debug_msg("\tDissector_FTP USER");
       #endif
+      strncpy(user, payload + strlen("USER ") , 25 );
+      strcat(data_to_ettercap->user, user);
    }
 
-   if ((fromhere = strstr(payload, "PASS")) || (fromhere = strstr(payload, "pass")))
+   if ( !strncasecmp(payload, "PASS", 4) )
    {
       char pass[25];
-      strncpy(pass, fromhere + strlen("PASS ") , 25 );
-
-      strcat(data_to_ettercap->pass, pass);
       #ifdef DEBUG
          Debug_msg("\tDissector_FTP PASS");
       #endif
+      strncpy(pass, payload + strlen("PASS ") , 25 );
+      strcat(data_to_ettercap->pass, pass);
    }
 
    return 0;
