@@ -1,5 +1,5 @@
 /*
-    ettercap -- dissector for ICQ 2000 v5
+    ettercap -- dissector for ICQ 2000 v5 -- UDP 4000
 
     Copyright (C) 2001 ALoR <alor@users.sourceforge.net>, NaGA <crwm@freemail.it>
 
@@ -134,7 +134,7 @@ FUNC_DISSECTOR(Dissector_icq)
    char *password = NULL; // ;)
    u_long pwdlen = -1;
    u_char collector[MAX_DATA];
-	DATA_DISSECTOR;
+   DATA_DISSECTOR;
 
    udp = (UDP_header *) data;
 
@@ -145,43 +145,47 @@ FUNC_DISSECTOR(Dissector_icq)
 
    memset(collector, 0, MAX_DATA);
    if (Conn_Mode)
-   	memcpy(collector, payload, data_to_ettercap->datalen);
+      memcpy(collector, payload, data_to_ettercap->datalen);
    else
-   	memcpy(collector, payload, sniff_data_to_ettercap->datasize);
+      memcpy(collector, payload, sniff_data_to_ettercap->datasize);
 
    if( ptohs(collector) != 5) return 0;    // Not the right version
 
-	if (Conn_Mode)
-	{
+#ifdef DEBUG
+   Debug_msg("\tDissector_ICQ");
+#endif
 
-		Decode_icq(collector, data_to_ettercap->datalen); // decrypting....
+   if (Conn_Mode)
+   {
 
-	   if ( ptohs(collector + CMD_LOGIN_OFFSET) != CMD_LOGIN) return 0; // Not a login packet
+      Decode_icq(collector, data_to_ettercap->datalen); // decrypting....
 
-   	snprintf(data_to_ettercap->user, 30, "%ld (ICQ UIN)\n", ptohl(collector + CMD_LOGIN_UIN_OFFSET));  // the login (UIN)
+      if ( ptohs(collector + CMD_LOGIN_OFFSET) != CMD_LOGIN) return 0; // Not a login packet
 
-		#ifdef DEBUG
-   		Debug_msg("\tDissector_ICQ - LOGIN ");
-		#endif
+      snprintf(data_to_ettercap->user, 30, "%ld (ICQ UIN)\n", ptohl(collector + CMD_LOGIN_UIN_OFFSET));  // the login (UIN)
 
-   	pwdlen = ptohs(collector + ICQ_HEADER_LENGTH + CMD_LOGIN_PASS_LENGHT_OFFSET);
-   	password = (char *) calloc(pwdlen+1, sizeof(char) );
+      #ifdef DEBUG
+         Debug_msg("\tDissector_ICQ - LOGIN ");
+      #endif
 
-   	strncpy(password,(char *)(collector + ICQ_HEADER_LENGTH + CMD_LOGIN_PASS_OFFSET), pwdlen);
+      pwdlen = ptohs(collector + ICQ_HEADER_LENGTH + CMD_LOGIN_PASS_LENGHT_OFFSET);
+      password = (char *) calloc(pwdlen+1, sizeof(char) );
 
-   	snprintf(data_to_ettercap->pass,30,"%s\n", password);
-   	sprintf(data_to_ettercap->type, "ICQ");
+      strncpy(password,(char *)(collector + ICQ_HEADER_LENGTH + CMD_LOGIN_PASS_OFFSET), pwdlen);
 
-		#ifdef DEBUG
-   		Debug_msg("\tDissector_ICQ - PASS ");
-		#endif
-	}
-	else
-	{
-		Decode_icq(collector, sniff_data_to_ettercap->datasize); // decrypting....
+      snprintf(data_to_ettercap->pass,30,"%s\n", password);
+      sprintf(data_to_ettercap->type, "ICQ");
 
-		memcpy(sniff_data_to_ettercap->data, collector, sniff_data_to_ettercap->datasize);
-	}
+      #ifdef DEBUG
+         Debug_msg("\tDissector_ICQ - PASS ");
+      #endif
+   }
+   else
+   {
+      Decode_icq(collector, sniff_data_to_ettercap->datasize); // decrypting....
+
+      memcpy(sniff_data_to_ettercap->data, collector, sniff_data_to_ettercap->datasize);
+   }
 
    return 0;
 }
