@@ -1,5 +1,5 @@
 /*
-    ettercap -- dissector MySQL
+    ettercap -- dissector MySQL -- TCP 3306
 
     Copyright (C) 2001  ALoR <alor@users.sourceforge.net>, NaGA <crwm@freemail.it>
 
@@ -46,8 +46,8 @@ FUNC_DISSECTOR(Dissector_mysql)
    TCP_header *tcp;
    u_char *payload;
    u_char collector[MAX_DATA];
+   static char auth_step = 0;
    char seed[8];
-
    ONLY_CONNECTION;
 
    tcp = (TCP_header *) data;
@@ -59,20 +59,26 @@ FUNC_DISSECTOR(Dissector_mysql)
    memset(collector, 0, MAX_DATA);
    memcpy(collector, payload, data_to_ettercap->datalen);
 
-   if (ntohs(tcp->source) == 3306)            // server messages... collect the random seed
+   if (!auth_step && ntohs(tcp->source) == 3306)            // server messages... collect the random seed
    {
-      int i = 5;  // skip first five byte and search for 000 padding
-      while(collector[i] != collector[i-1] != collector[i-2] != 0)
+      int i = 5;  // skip first five byte
+
+      if (memcmp(collector, "\x28\x00\x00\x00\x0a", 2)) return 0;    // magic number... ;)
+
+      #ifdef DEBUG
+         Debug_msg("\tDissector_MySQL server");
+      #endif
+
+      while(collector[i] != collector[i-1] != collector[i-2] != 0)   // search for 000 padding
          i++;
 
       strncpy(seed, collector + i + 1, 8);
-//      #ifdef DEBUG
-//       printf("\nserver:\n%s\n", Decodedata_GetHexData(payload, data_to_ettercap->datalen, 80));
-//       Debug_msg("\tDissector_mysql - seed - [ %s ]", seed);
-//      #endif
       sprintf(data_to_ettercap->info, "Encrypted (one way) seed: %s  pass: ", seed);
+
+      auth_step = 1;
    }
-   else                                      // client response crypt pass with seed
+
+   if ( (auth_step == 1) && ntohs(tcp->source) != 3306)  // client response crypt pass with seed
    {
       char user[25];
       char pass[25];
@@ -92,14 +98,10 @@ FUNC_DISSECTOR(Dissector_mysql)
       strcat(data_to_ettercap->info, "\n");
       sprintf(data_to_ettercap->type, "MySQL");
 
-//      #ifdef DEBUG
-//       printf("\nclient:\n%s\n", Decodedata_GetHexData(payload, data_to_ettercap->datalen, 80));
-//         Debug_msg("\tDissector_mysql - user - [%s]", user);
-//         Debug_msg("\tDissector_mysql - pass - [%s]", pass);
-//      #endif
-   }
-   return 0;
+      auth_step = 0;
+    }
+
+    return 0;
 }
 
-
 /* EOF */
