@@ -1,5 +1,5 @@
 /*
-    ettercap -- dissector POP3
+    ettercap -- dissector POP3 -- TCP 110
 
     Copyright (C) 2001  ALoR <alor@users.sourceforge.net>, NaGA <crwm@freemail.it>
 
@@ -45,36 +45,48 @@ FUNC_DISSECTOR(Dissector_pop)
 
    TCP_header *tcp;
    u_char *payload;
-   char *fromhere;
-   
    ONLY_CONNECTION;
-   
+
    tcp = (TCP_header *) data;
 
    if (ntohs(tcp->source) == 110) return 0;           // skip server messages...
 
    payload = (char *)((int)tcp + tcp->doff * 4);
 
-   if ((fromhere = strstr(payload, "USER")) || (fromhere = strstr(payload, "user")))
+   if ( !strncasecmp(payload, "USER", 4) )
    {
       char user[25];
-      strncpy(user, fromhere + strlen("USER ") , 25 );
-
-      strcat(data_to_ettercap->user, user);
       #ifdef DEBUG
          Debug_msg("\tDissector_POP USER");
       #endif
+      strncpy(user, payload + strlen("USER ") , 25 );
+      strcat(data_to_ettercap->user, user);
    }
 
-   if ((fromhere = strstr(payload, "PASS")) || (fromhere = strstr(payload, "pass")))
+   if ( !strncasecmp(payload, "PASS", 4) )
    {
       char pass[25];
-      strncpy(pass, fromhere + strlen("PASS ") , 25 );
-
-      strcat(data_to_ettercap->pass, pass);
       #ifdef DEBUG
          Debug_msg("\tDissector_POP PASS");
       #endif
+      strncpy(pass, payload + strlen("PASS ") , 25 );
+      strcat(data_to_ettercap->pass, pass);
+   }
+
+   if ( !strncasecmp(payload, "APOP", 4) )
+   {
+      char user[25];
+      char *p;
+      #ifdef DEBUG
+         Debug_msg("\tDissector_POP APOP");
+      #endif
+
+      strncpy(user, strtok(payload + strlen("APOP "), " ") , 25 );
+      strcat(data_to_ettercap->user, user);
+      strcat(data_to_ettercap->user, "\n");
+      strcat(data_to_ettercap->pass, "\n");
+      p = strtok(NULL, " ");
+      sprintf(data_to_ettercap->info, "Authenticated with APOP %s\n", (p) ? p : "");
    }
 
    return 0;
