@@ -1,4 +1,5 @@
-/*    ettercap -- dissector SSH
+/*
+    ettercap -- dissector SSH -- TCP 22
 
     Copyright (C) 2001  ALoR <alor@users.sourceforge.net>, NaGA <crwm@freemail.it>
 
@@ -233,11 +234,6 @@ void reconstruct_stream(u_char *ibuf, short bufflen, u_char *obuf)
    datalen = (u_short *)(obuf + 2);
    *datalen += bufflen;
 
-//#ifdef DEBUG
-// Debug_msg("\t\t\t STREAM PUT %d %d -- %d", *fromhere, bufflen, *datalen);
-////  Debug_msg("\n\n%s\n\n", Decodedata_GetHexData(obuf+4, *datalen, 80));
-//#endif
-
 }
 
 int getfrom_stream(u_char *ibuf, u_char *obuf)
@@ -253,31 +249,17 @@ int getfrom_stream(u_char *ibuf, u_char *obuf)
    ssh_len = ntohl(ptohl(ibuf + 4 + *fromhere));
    ssh_mod = 8 - (ssh_len % 8);
 
-//#ifdef DEBUG
-// Debug_msg("\t\t\t GETFROM STREAM datalen %d -- form %d -- ssh %d", *datalen, *fromhere, ssh_len+ssh_mod+4);
-////   Debug_msg("\n\n%s\n\n", Decodedata_GetHexData(ibuf + 4 + *fromhere, len, 80));
-//#endif
-
    *datalen -= (ssh_len+ssh_mod+4);
 
    if (*datalen < 0)
    {
-//#ifdef DEBUG
-// Debug_msg("\t\t\t STREAM MOVE from %d  datalen %d  ssh %d -- newfrom %d", *fromhere, *datalen, ssh_len+ssh_mod+4, *datalen + ssh_len+ssh_mod+4);
-//#endif
       memmove(ibuf + 4 , ibuf + 4 + *fromhere, *datalen + ssh_len+ssh_mod+4); // move the rest
       *fromhere = *datalen + ssh_len+ssh_mod+4;
       *datalen += ssh_len+ssh_mod+4;
-//#ifdef DEBUG
-// Debug_msg("\t\t\t STREAM AFTER MOVE -- from %d  datalen %d ", *fromhere, *datalen);
-//#endif
       return 0;
    }
    else
    {
-//#ifdef DEBUG
-// Debug_msg("\t\t\t STREAM GET from %d  datalen %d  ssh %d", *fromhere, *datalen, ssh_len+ssh_mod+4);
-//#endif
       memcpy(obuf, ibuf + 4 + *fromhere, ssh_len+ssh_mod+4);
       if (*datalen == 0)
          *fromhere = 0;
@@ -300,7 +282,7 @@ FUNC_DISSECTOR(Dissector_ssh)
    u_short PORTS, PORTD;
    static int initialized=0;
    int direction=0;
-	DATA_DISSECTOR;
+   DATA_DISSECTOR;
 
    if (!initialized) { SSL_library_init(); initialized=1; }
 
@@ -332,13 +314,6 @@ FUNC_DISSECTOR(Dissector_ssh)
    ssh_len = ntohl(ssh_len);
    ssh_mod = 8 - (ssh_len % 8);
 
-#ifdef DEBUG
-   Debug_msg("\t PAYLOAD DATALEN %d -- %d",  datalen, ssh_len+ssh_mod+4);
-   if (ssh_len > STREAM_DATA) Debug_msg("\t\t\t\t\t\t\t to be reconstructed");
-// Debug_msg("\n\n%s\n\n", Decodedata_GetHexData(payload, datalen, 80));
-#endif
-
-
    // Find interesting packets
    //if (ssh_len + 4 + ssh_mod <= datalen)
    {
@@ -427,54 +402,54 @@ FUNC_DISSECTOR(Dissector_ssh)
                ssh_len = ntohl(ssh_len);
                ssh_mod = 8 - (ssh_len % 8);
 
-#ifdef DEBUG
-   Debug_msg("\t STREAM DATALEN %d -- %d",  slen, ssh_len+ssh_mod+4);
-   //Debug_msg("\n\n%s\n\n", Decodedata_GetHexData(packet, slen, 80));
-#endif
                memset(pacchetto, 0, MAX_DATA);
 
-               // Simple workaround for duplicated packets
                if (direction==1)
                   des3_decrypt(packet+4, (u_char *)pacchetto, ssh_len+ssh_mod, (*index)->state_source);
                else
                   des3_decrypt(packet+4, (u_char *)pacchetto, ssh_len+ssh_mod, (*index)->state_dest);
 
-//#ifdef DEBUG
-// Debug_msg("\t STREAM DECRYPTED %d -- %d",  slen, ssh_len+ssh_mod+4);
-// //Debug_msg("\n\n%s\n\n", Decodedata_GetHexData(packet, slen, 80));
-//#endif
-
                if (Conn_Mode)
                {
                   int len;
                   len = ptohl(pacchetto+ssh_mod+1);
                   len = htonl(len);
 
-//#ifdef DEBUG
-// Debug_msg("\t conn_mode len = %d  ", len);
-//#endif
-
                   if (pacchetto[ssh_mod]==4) // SSH_CMSG_USER
                   {
+                     #ifdef DEBUG
+                        Debug_msg("\tDissector_ssh USER");
+                     #endif
                      memcpy(data_to_ettercap->user,&pacchetto[ssh_mod+5],len);
                      strcat(data_to_ettercap->user,"\n");
                   }
 
                   if (pacchetto[ssh_mod]==9) // SSH_AUTH_PASSWORD
                   {
+                     #ifdef DEBUG
+                        Debug_msg("\tDissector_ssh PASS");
+                     #endif
                      memcpy(data_to_ettercap->pass,&pacchetto[ssh_mod+5],len);
                      strcat(data_to_ettercap->pass,"\n");
                   }
 
                   if (pacchetto[ssh_mod]==5)
                   {
+                     #ifdef DEBUG
+                        Debug_msg("\tDissector_ssh RHOSTS");
+                     #endif
                      strcpy(data_to_ettercap->pass,"RHOSTS:");
                      strncat(data_to_ettercap->pass,&pacchetto[ssh_mod+5],len);
                      strcat(data_to_ettercap->pass,"\n");
                   }
 
                   if (pacchetto[ssh_mod]==6)
+                  {
+                     #ifdef DEBUG
+                        Debug_msg("\tDissector_ssh RSA");
+                     #endif
                      strcpy(data_to_ettercap->pass,"RSA AUTH\n");
+                  }
                }
                else
                {
@@ -489,11 +464,6 @@ FUNC_DISSECTOR(Dissector_ssh)
                      sniff_data_to_ettercap->datasize+=len;
                      if (sniff_data_to_ettercap->datasize < MAX_DATA)
                         strncat(sniff_data_to_ettercap->data,&pacchetto[ssh_mod+5],len);
-
-#ifdef DEBUG
-   Debug_msg("\t len = %d  -- ettercap len %d", len, sniff_data_to_ettercap->datasize);
-   //Debug_msg("\n\n%s\n\n",Decodedata_GetAsciiData(sniff_data_to_ettercap->data, sniff_data_to_ettercap->datasize));
-#endif
                   }
                }
 
