@@ -69,15 +69,23 @@ char * Fingerprint_MAC(char *MAC);
 
 int Fingerprint_Match(char *mycond, char *fpcond)
 {
-   int matched=0; char *single_cond, *deadend=NULL;
+   int matched=0; char *single_cond, *deadend=NULL, temp=0;
 
    deadend=fpcond+strlen(fpcond);
    if (deadend==fpcond) matched=1;
    while( !matched && (unsigned long)fpcond<(unsigned long)deadend )
    {
       single_cond=(char *)strtok(fpcond,"|");
-		if (!strcmp(mycond,single_cond)) matched=1;
-		fpcond+=strlen(single_cond)+1;
+      if (!single_cond) // Simple workaround for initial '|'
+      {                 // Arghhh someone wrotedown terrible fingerprints
+          if (temp) break;
+          fpcond++;
+     temp=1;
+          continue;
+      }
+     if (!strcmp(mycond,single_cond)) matched=1;
+     fpcond+=strlen(single_cond)+1;
+     temp=0;
    }
    return matched;
 }
@@ -104,30 +112,30 @@ void Fingerprint_send_probes()
    Inet_Forge_Insert_TCPOpt( probe_pck + ETH_HEADER + IP_HEADER, OPTIONS ,OPT_LEN );
    Inet_SendRawPacket(sock, probe_pck, ETH_HEADER + IP_HEADER + TCP_HEADER + OPT_LEN);
 
- 	Inet_Forge_ip( probe_pck + ETH_HEADER, IPS, IPD, TCP_HEADER, IP_ID++, 0, IPPROTO_TCP);
+   Inet_Forge_ip( probe_pck + ETH_HEADER, IPS, IPD, TCP_HEADER, IP_ID++, 0, IPPROTO_TCP);
    Inet_Forge_tcp( probe_pck + ETH_HEADER + IP_HEADER, PORTS+2, open_port,  SYN_SEQ, 0, TH_SYN|TH_FIN|TH_URG|TH_PSH, 0, 0);
    Inet_Forge_Insert_TCPOpt( probe_pck + ETH_HEADER + IP_HEADER, OPTIONS ,OPT_LEN );
-	Inet_SendRawPacket(sock, probe_pck, ETH_HEADER + IP_HEADER + TCP_HEADER + OPT_LEN);
+   Inet_SendRawPacket(sock, probe_pck, ETH_HEADER + IP_HEADER + TCP_HEADER + OPT_LEN);
 
-	Inet_Forge_ip( probe_pck + ETH_HEADER, IPS, IPD, TCP_HEADER, IP_ID++, 0, IPPROTO_TCP);
+   Inet_Forge_ip( probe_pck + ETH_HEADER, IPS, IPD, TCP_HEADER, IP_ID++, 0, IPPROTO_TCP);
    Inet_Forge_tcp( probe_pck + ETH_HEADER + IP_HEADER, PORTS+3, open_port,  SYN_SEQ, 0, TH_ACK, 0, 0);
    Inet_Forge_Insert_TCPOpt( probe_pck + ETH_HEADER + IP_HEADER, OPTIONS ,OPT_LEN );
-	Inet_SendRawPacket(sock, probe_pck, ETH_HEADER + IP_HEADER + TCP_HEADER + OPT_LEN );
+   Inet_SendRawPacket(sock, probe_pck, ETH_HEADER + IP_HEADER + TCP_HEADER + OPT_LEN );
 
-	Inet_Forge_ip( probe_pck + ETH_HEADER, IPS, IPD, TCP_HEADER, IP_ID++, 0, IPPROTO_TCP);
+   Inet_Forge_ip( probe_pck + ETH_HEADER, IPS, IPD, TCP_HEADER, IP_ID++, 0, IPPROTO_TCP);
    Inet_Forge_tcp( probe_pck + ETH_HEADER + IP_HEADER, PORTS+4, closed_port,  SYN_SEQ, 0, TH_SYN, 0, 0);
    Inet_Forge_Insert_TCPOpt( probe_pck + ETH_HEADER + IP_HEADER, OPTIONS ,OPT_LEN );
-	Inet_SendRawPacket(sock, probe_pck, ETH_HEADER + IP_HEADER + TCP_HEADER + OPT_LEN );
+   Inet_SendRawPacket(sock, probe_pck, ETH_HEADER + IP_HEADER + TCP_HEADER + OPT_LEN );
 
-	Inet_Forge_ip( probe_pck + ETH_HEADER, IPS, IPD, TCP_HEADER, IP_ID++, 0, IPPROTO_TCP);
+   Inet_Forge_ip( probe_pck + ETH_HEADER, IPS, IPD, TCP_HEADER, IP_ID++, 0, IPPROTO_TCP);
    Inet_Forge_tcp( probe_pck + ETH_HEADER + IP_HEADER, PORTS+5, closed_port,  SYN_SEQ, 0, TH_ACK, 0, 0);
    Inet_Forge_Insert_TCPOpt( probe_pck + ETH_HEADER + IP_HEADER, OPTIONS ,OPT_LEN );
-	Inet_SendRawPacket(sock, probe_pck, ETH_HEADER + IP_HEADER + TCP_HEADER + OPT_LEN );
+   Inet_SendRawPacket(sock, probe_pck, ETH_HEADER + IP_HEADER + TCP_HEADER + OPT_LEN );
 
-  	Inet_Forge_ip( probe_pck + ETH_HEADER, IPS, IPD, TCP_HEADER, IP_ID++, 0, IPPROTO_TCP);
+   Inet_Forge_ip( probe_pck + ETH_HEADER, IPS, IPD, TCP_HEADER, IP_ID++, 0, IPPROTO_TCP);
    Inet_Forge_tcp( probe_pck + ETH_HEADER + IP_HEADER, PORTS+6, closed_port,  SYN_SEQ, 0, TH_FIN|TH_PSH|TH_URG, 0, 0);
    Inet_Forge_Insert_TCPOpt( probe_pck + ETH_HEADER + IP_HEADER, OPTIONS ,OPT_LEN );
-	Inet_SendRawPacket(sock, probe_pck, ETH_HEADER + IP_HEADER + TCP_HEADER + OPT_LEN );
+   Inet_SendRawPacket(sock, probe_pck, ETH_HEADER + IP_HEADER + TCP_HEADER + OPT_LEN );
 
    Inet_Forge_packet_destroy( probe_pck );
 }
@@ -147,87 +155,87 @@ void Fingerprint_parse_probes()
 
    do
    {
-	len=Inet_GetRawPacket(sock,probe_pck,MTU,&type);
-	TIME_FINISH;
+   len=Inet_GetRawPacket(sock,probe_pck,MTU,&type);
+   TIME_FINISH;
 
-	if (len>0 && type==PACKET_HOST)
-	{
-	   eth=(ETH_header *)probe_pck;
-	   if (ntohs(eth->type)==ETH_P_IP)
-	   {
-		ip=(IP_header *)(probe_pck+ETH_HEADER);
-		if (ip->proto==IPPROTO_TCP && ip->source_ip==IPD)
-		{
-		   tcp=(TCP_header *)(probe_pck+ETH_HEADER+IP_HEADER);
+   if (len>0 && type==PACKET_HOST)
+   {
+      eth=(ETH_header *)probe_pck;
+      if (ntohs(eth->type)==ETH_P_IP)
+      {
+      ip=(IP_header *)(probe_pck+ETH_HEADER);
+      if (ip->proto==IPPROTO_TCP && ip->source_ip==IPD)
+      {
+         tcp=(TCP_header *)(probe_pck+ETH_HEADER+IP_HEADER);
 
-		   if ( (u_short)ntohs(tcp->dest)>=PORTS && (u_short)ntohs(tcp->dest)<PORTS+NUM_TESTS)
-		   {
-			char *p, *q, *arrive;
-			unsigned int num_test;
+         if ( (u_short)ntohs(tcp->dest)>=PORTS && (u_short)ntohs(tcp->dest)<PORTS+NUM_TESTS)
+         {
+         char *p, *q, *arrive;
+         unsigned int num_test;
 
-			num_test=ntohs(tcp->dest)-PORTS;
+         num_test=ntohs(tcp->dest)-PORTS;
 
-			// Replied
-			strcpy(&packet_stamp[num_test][0][0],"Y");
-   			// DF flag
-			if(ntohs(ip->frag_and_flags) & 0x4000)
-			{
-			   strcpy(&packet_stamp[num_test][1][0],"Y");
-			}
-			else strcpy(&packet_stamp[num_test][1][0], "N");
-			// Window Size
-			sprintf(&packet_stamp[num_test][2][0],"%hX",ntohs(tcp->window));
-			// ACK Sequence
-			if (ntohl(tcp->ack_seq) == SYN_SEQ+1)
-			   strcpy(&packet_stamp[num_test][3][0],"S++");
-			else if (ntohl(tcp->ack_seq) == SYN_SEQ)
-			   strcpy(&packet_stamp[num_test][3][0],"S");
-			else
-			   strcpy(&packet_stamp[num_test][3][0],"O");
-			// Flags
-			p=&packet_stamp[num_test][4][0];
-			*p='\0';
-			if (tcp->flags & 0x40)   *p++='B'; // BOGUS
-			if (tcp->flags & TH_URG) *p++='U';
-			if (tcp->flags & TH_ACK) *p++='A';
-			if (tcp->flags & TH_PSH) *p++='P';
-			if (tcp->flags & TH_RST) *p++='R';
-			if (tcp->flags & TH_SYN) *p++='S';
-			if (tcp->flags & TH_FIN) *p++='F';
-			*p++='\0';
-			// TCP Options
-			p=&packet_stamp[num_test][5][0];
-			q=((char *)tcp) + TCP_HEADER;
-			arrive = ((char *)tcp) + (tcp->doff*4);
-			while(q<arrive)
-			{
-			   int opcode;
+         // Replied
+         strcpy(&packet_stamp[num_test][0][0],"Y");
+            // DF flag
+         if(ntohs(ip->frag_and_flags) & 0x4000)
+         {
+            strcpy(&packet_stamp[num_test][1][0],"Y");
+         }
+         else strcpy(&packet_stamp[num_test][1][0], "N");
+         // Window Size
+         sprintf(&packet_stamp[num_test][2][0],"%hX",ntohs(tcp->window));
+         // ACK Sequence
+         if (ntohl(tcp->ack_seq) == SYN_SEQ+1)
+            strcpy(&packet_stamp[num_test][3][0],"S++");
+         else if (ntohl(tcp->ack_seq) == SYN_SEQ)
+            strcpy(&packet_stamp[num_test][3][0],"S");
+         else
+            strcpy(&packet_stamp[num_test][3][0],"O");
+         // Flags
+         p=&packet_stamp[num_test][4][0];
+         *p='\0';
+         if (tcp->flags & 0x40)   *p++='B'; // BOGUS
+         if (tcp->flags & TH_URG) *p++='U';
+         if (tcp->flags & TH_ACK) *p++='A';
+         if (tcp->flags & TH_PSH) *p++='P';
+         if (tcp->flags & TH_RST) *p++='R';
+         if (tcp->flags & TH_SYN) *p++='S';
+         if (tcp->flags & TH_FIN) *p++='F';
+         *p++='\0';
+         // TCP Options
+         p=&packet_stamp[num_test][5][0];
+         q=((char *)tcp) + TCP_HEADER;
+         arrive = ((char *)tcp) + (tcp->doff*4);
+         while(q<arrive)
+         {
+            int opcode;
 
-			   opcode=*q++;
-			   if (!opcode) {
-				*p++ = 'L';
-				break;
-			   } else if (opcode == 1) {
-			     *p++ = 'N';
-			   } else if (opcode == 2) {
-			     *p++ = 'M';
-			     q++;
-			     if (ntohs(ptohs(q)) == MSS)
-			      *p++ = 'E';
-			     q+=2;
-			   } else if (opcode == 3) {
-			     *p++ = 'W';
-			     q+=2;
-			   } else if (opcode == 8) {
-			     *p++ = 'T';
-			     q+=9;
-			   }
-			}
-			*p++='\0';
-		   }
-		}
-	   }
-	}
+            opcode=*q++;
+            if (!opcode) {
+            *p++ = 'L';
+            break;
+            } else if (opcode == 1) {
+              *p++ = 'N';
+            } else if (opcode == 2) {
+              *p++ = 'M';
+              q++;
+              if (ntohs(ptohs(q)) == MSS)
+               *p++ = 'E';
+              q+=2;
+            } else if (opcode == 3) {
+              *p++ = 'W';
+              q+=2;
+            } else if (opcode == 8) {
+              *p++ = 'T';
+              q+=9;
+            }
+         }
+         *p++='\0';
+         }
+      }
+      }
+   }
    }while(TIME_ELAPSED<1);
 
    Inet_Forge_packet_destroy( probe_pck );
@@ -278,51 +286,47 @@ char *Fingerprint_Make_Finger_print()
    Fingerprint_Init_Test();
    Fingerprint_send_probes();
    Fingerprint_parse_probes();
-	res_list[0]=0;
+   res_list[0]=0;
 
    loop
    {
-		char *To_EOF;
+      char *To_EOF;
 
-		while( (To_EOF=fgets(osname,500,file)) && !strstr(osname,"Fingerprint") );
-		if (!To_EOF) break;
-		no_match=0;
+      while( (To_EOF=fgets(osname,500,file)) && !strstr(osname,"Fingerprint") );
+      if (!To_EOF) break;
+      no_match=0;
+      for (i=1; i<=7 && !no_match; i++)
+      {
+         char *deadend;
 
-		for (i=1; i<=7 && !no_match; i++)
-		{
-		   char *deadend;
+         sprintf(num_test,"T%1d",i);
+         while(fgets(dummy,500,file) && !strstr(dummy,num_test));
 
-		   sprintf(num_test,"T%1d",i);
-		   while(fgets(dummy,500,file) && !strstr(dummy,num_test));
+         test=dummy+3;
+         dummy[strlen(dummy)-2]=0;
+         deadend=test+strlen(test);
 
-		   test=dummy+3;
-		   dummy[strlen(dummy)-2]=0;
-		   deadend=test+strlen(test);
-
-		   while( !no_match &&  (unsigned long)test<(unsigned long)deadend )
-		   {
-				int j; char *pos=NULL;
-
-				condition=(char *)strtok(test,"%");
-				test+=strlen(condition)+1;
-				for (j=0; j<NUM_CONDS && pos!=condition; j++)
-			   	pos=(char *)strstr(condition,test_name[j]);
-				condition +=  strlen(test_name[j-1])+1;
-				if ( !Fingerprint_Match(&packet_stamp[i-1][j-1][0],condition) ) no_match=1;
-		   }
-		}
-		if (!no_match)
-		{
-	   	strcat(res_list,osname+sizeof("Fingerprint"));
-	 	}
+         while( !no_match &&  (unsigned long)test<(unsigned long)deadend )
+         {
+            int j; char *pos=NULL;
+            condition=(char *)strtok(test,"%");
+            test+=strlen(condition)+1;
+            for (j=0; j<NUM_CONDS && pos!=condition; j++)
+               pos=(char *)strstr(condition,test_name[j]);
+            condition +=  strlen(test_name[j-1])+1;
+            if ( !Fingerprint_Match(&packet_stamp[i-1][j-1][0],condition) ) no_match=1;
+         }
+      }
+      if (!no_match)
+      {
+         strcat(res_list,osname+sizeof("Fingerprint"));
+      }
    }
-
    fclose(file);
 
-	if (!strcmp(res_list, ""))
-		strcpy(res_list, "Not found in the database\n");
+   if (!strcmp(res_list, ""))
+      strcpy(res_list, "Not found in the database\n");
 
-   //if ( res_list[strlen(res_list)-1] == '\n') res_list[strlen(res_list)-1] = 0;		// trim the trailing \n
    return res_list;
 
 }
@@ -377,27 +381,27 @@ void Fingerprint_Simple_Scan()
 
 char * Fingerprint_OS(char *IP)
 {
-	char *res_name;
+   char *res_name;
 
 #ifdef DEBUG
    Debug_msg("Fingerprint_OS -- [%s]", IP);
 #endif
 
-	if (!strcmp(IP, Inet_MyIPAddress()))
-	{
-		#ifdef HAVE_SYS_UTSNAME_H
-			struct utsname buf;
+   if (!strcmp(IP, Inet_MyIPAddress()))
+   {
+      #ifdef HAVE_SYS_UTSNAME_H
+         struct utsname buf;
 
-			res_name = (char *)malloc(50);
-			uname(&buf);
-			strcpy(res_name, buf.sysname);
-			strcat(res_name, " ");
-			strcat(res_name, buf.release);
-			return res_name;
-		#else
-			return "Yourself ;) try `uname -sr`";
-		#endif
-	}
+         res_name = (char *)malloc(50);
+         uname(&buf);
+         strcpy(res_name, buf.sysname);
+         strcat(res_name, " ");
+         strcat(res_name, buf.release);
+         return res_name;
+      #else
+         return "Yourself ;) try `uname -sr`";
+      #endif
+   }
 
    IPD = inet_addr(IP);
    sock = Inet_OpenRawSock(Options.netiface);
@@ -406,20 +410,20 @@ char * Fingerprint_OS(char *IP)
    memcpy(MACD, Inet_MacFromIP(inet_addr(IP)), 6);
    srand(time(0)); IP_ID = PORTS = SYN_SEQ = rand()%(0xFFFE)+1;
 
-	open_port = 0;
-	closed_port = 0;
+   open_port = 0;
+   closed_port = 0;
 
    Fingerprint_Simple_Scan();
-
    if (!open_port || !closed_port)
       return "Can't find ports to probe";
    else
    {
-		res_name = Fingerprint_Make_Finger_print();
-		if (!res_name)
-   	   return "No match in database";
-		else
-	   	return res_name;
+      res_name = Fingerprint_Make_Finger_print();
+      close(sock);
+      if (!res_name)
+         return "No match in database";
+      else
+         return res_name;
    }
 
 }
