@@ -34,6 +34,7 @@
 #include "include/ec_buffer.h"
 #include "include/ec_error.h"
 #include "include/ec_dissector.h"
+#include "include/ec_filterdrop.h"
 
 #ifdef DEBUG
    #include "include/ec_debug.h"
@@ -81,17 +82,13 @@ void Illithid_Reset_Conn(void)
       pck_to_send += Inet_Forge_ethernet( pck_to_send, MyMAC, MAC2, ETH_P_IP );
       pck_to_send += Inet_Forge_ip( pck_to_send, IP1, IP2, TCP_HEADER, IPIDD+PacketSentD+1, 0, IPPROTO_TCP);
       pck_to_send += Inet_Forge_tcp( pck_to_send, G_PortSource, G_PortDest, SeqD+datalenD+ByteSentD, AckD-ByteSentS, TH_RST | TH_ACK, 0, 0);
-#ifdef DEBUG
-   Debug_msg("Illithid_Reset_Conn -- packet 1");
-#endif
+
       buf2 = Inet_Forge_packet( ETH_HEADER + IP_HEADER + TCP_HEADER );
       pck_to_send = buf2;
       pck_to_send += Inet_Forge_ethernet( pck_to_send, MyMAC, MAC1, ETH_P_IP );
       pck_to_send += Inet_Forge_ip( pck_to_send, IP2, IP1, TCP_HEADER, IPIDS+PacketSentS+1, 0, IPPROTO_TCP);
       pck_to_send += Inet_Forge_tcp( pck_to_send, G_PortDest, G_PortSource, SeqS+datalenS+ByteSentS, AckS-ByteSentD, TH_RST | TH_ACK, 0, 0);
-#ifdef DEBUG
-   Debug_msg("Illithid_Reset_Conn -- packet 2");
-#endif
+
       for(i=0; i<5; i++)
       {
          Inet_SendRawPacket(sock, buf1, ETH_HEADER + IP_HEADER + TCP_HEADER );
@@ -106,18 +103,20 @@ void Illithid_Reset_Conn(void)
 
 int Illithid_ARPBased_GetData(char *iface, char proto, char *IPsource, int PortSource, char *IPdest, int PortDest, char *MAC1p, char *MAC2p)
 {
-   int MTU, Illithid_pid;
+   int MTU, Illithid_pid, delta, datalen;
    short pkttype;
    struct in_addr addr;
    ETH_header *eth;
    IP_header *ip;
    TCP_header *tcp;
+   UDP_header *udp;
    unsigned char *data;
-   char nchars;
-   char tosendchar[150];
+   int nchars;
+   char tosendchar[MAX_INJECT];
    char *ins_pck;
    u_char *buffer;
    SNIFFED_DATA data_to_test;
+   DROP_FILTER filter;
 
 #ifdef DEBUG
    Debug_msg("Illithid_ARPBased_GetData -- %c [%s:%d] [%s:%d] -- [%s] [%s]", proto, IPsource, PortSource, IPdest, PortDest, MAC1, MAC2);
@@ -147,15 +146,18 @@ int Illithid_ARPBased_GetData(char *iface, char proto, char *IPsource, int PortS
    fcntl(sock,F_SETFL,O_NONBLOCK);
    fcntl(pipe_inject_stod[0], F_SETFL, O_NONBLOCK);
    fcntl(pipe_inject_dtos[0], F_SETFL, O_NONBLOCK);
+   fcntl(pipe_filter_stod[0], F_SETFL, O_NONBLOCK);
+   fcntl(pipe_filter_dtos[0], F_SETFL, O_NONBLOCK);
 
    ins_pck = Inet_Forge_packet(MTU);
    buffer = Inet_Forge_packet(MTU);
 
-   for (;;)
+   loop
    {
       int len;
       char ok;
 
+      if (getppid() == 1) exit(0);
       //memset(buffer, 0, MTU);
 
       len = Inet_GetRawPacket(sock, buffer, MTU, &pkttype);
@@ -183,29 +185,89 @@ int Illithid_ARPBased_GetData(char *iface, char proto, char *IPsource, int PortS
                ok = 2;
             }
 
+
+            if ( ok && ip->proto == IPPROTO_UDP && proto == 'U')
+            {
+               udp = (UDP_header *) ((int)ip + ip->h_len * 4);
+
+               if (ntohs(ip->frag_and_flags) & IP_OFFMASK) goto send;
+
+               strcpy(data_to_test.ip_source, int_ntoa(ip->source_ip) );
+               strcpy(data_to_test.ip_dest, int_ntoa(ip->dest_ip) );
+               data_to_test.source_port = ntohs(udp->source);
+               data_to_test.dest_port = ntohs(udp->dest);
+               data = (char *)((int)udp + UDP_HEADER);
+
+               if ( Illithid_ToBeSniffed(IPsource,PortSource, IPdest, PortDest, &data_to_test) )
+               {
+                  datalen = ntohs(udp->len) - UDP_HEADER;
+
+                  if (ok == 1)
+                  {
+                     len -= ETH_HEADER;
+                     delta = FilterDrop_MakefilterUDP((u_char *)ip, &len, MTU-40, &ARP_Filter_Source);
+                     len += ETH_HEADER;
+                  }
+                  else // ok == 2
+                  {
+                     len -= ETH_HEADER;
+                     delta = FilterDrop_MakefilterUDP((u_char *)ip, &len, MTU-40, &ARP_Filter_Dest);
+                     len += ETH_HEADER;
+                  }
+                  if (delta == -datalen) ok = 0;  // drop the packet (forwarding is done only if(ok) )
+               }
+
+            }
+
             if (ok && ip->proto == IPPROTO_TCP && proto == 'T')
             {
                tcp = (TCP_header *) ((int)ip + ip->h_len * 4);
 
                if (ntohs(ip->frag_and_flags) & IP_OFFMASK) goto send;
 
-               strcpy(data_to_test.ip_source, inet_ntoa(*(struct in_addr *)&ip->source_ip) );
-               strcpy(data_to_test.ip_dest, inet_ntoa(*(struct in_addr *)&ip->dest_ip) );
+               strcpy(data_to_test.ip_source, int_ntoa(ip->source_ip) );
+               strcpy(data_to_test.ip_dest, int_ntoa(ip->dest_ip) );
                data_to_test.source_port = ntohs(tcp->source);
                data_to_test.dest_port = ntohs(tcp->dest);
 
-               if ( Illithid_ToBeSniffed(IPsource,PortSource, IPdest, PortDest, &data_to_test) )
+               data = (char *)((int)tcp + tcp->doff * 4);
+
+               if ( Illithid_ToBeSniffed(IPsource, PortSource, IPdest, PortDest, &data_to_test) )
                {
-                  if (ok == 1)
+
+                  if (ok == 1)   // from source
                   {
+                     datalenS = (int)ip + ntohs(ip->t_len) - (int)data; // I need it before modifications....
+
+                     len -= ETH_HEADER;
+                     delta = FilterDrop_MakefilterTCP((u_char *)ip, &len, MTU-40, &ARP_Filter_Source);
+                     len += ETH_HEADER;
+
                      SeqS = ntohl(tcp->seq);
                      AckS = ntohl(tcp->ack_seq);
                      tcp->seq = htonl(SeqS+ByteSentS);
                      tcp->ack_seq = htonl(AckS-ByteSentD);
                      IPIDS = ntohs(ip->ident);
                      ip->ident = htons(IPIDS+PacketSentS);
-                     data = (char *)((int)tcp + tcp->doff * 4);
-                     datalenS = (int)ip + ntohs(ip->t_len) - (int)data;
+
+                     if (delta == -datalenS && datalenS != 0)     // the packet must be dropped, so we send an ACK
+                     {
+                        char *pck_to_send;
+                        #ifdef DEBUG
+                           Debug_msg("Illithid_ARPBased_GetData -- drop TCP ");
+                        #endif
+                        pck_to_send = ins_pck;
+                        pck_to_send += Inet_Forge_ethernet( pck_to_send, MyMAC, MAC2, ETH_P_IP );
+                        pck_to_send += Inet_Forge_ip( pck_to_send, IP1, IP2, TCP_HEADER, IPIDD+PacketSentD, 0, IPPROTO_TCP);
+                        pck_to_send += Inet_Forge_tcp( pck_to_send, PortSource, PortDest, ntohl(tcp->ack_seq), SeqS+datalenS, TH_ACK, 0, 0);
+
+                        Inet_SendRawPacket(sock, ins_pck, pck_to_send-ins_pck);
+                        PacketSentD++;
+                        ok = 0;  // drop the packet (forwarding is done only if(ok) )
+                     }
+                     ByteSentS += delta;
+
+                     datalenS = (int)ip + ntohs(ip->t_len) - (int)data; // now i store the modified datalen
 
                      ip->checksum = 0;
                      tcp->checksum = 0;
@@ -219,16 +281,39 @@ int Illithid_ARPBased_GetData(char *iface, char proto, char *IPsource, int PortS
                      }
                      tcp->checksum = Inet_Forge_Checksum((unsigned short *)tcp, IPPROTO_TCP, ntohs(ip->t_len)-ip->h_len*4, IP2, IP1);
                   }
-                  else
+                  else  // ok == 2  //from dest
                   {
+                     datalenD = (int)ip + ntohs(ip->t_len) - (int)data; // I need it before modifications....
+
+                     len -= ETH_HEADER;
+                     delta = FilterDrop_MakefilterTCP((u_char *)ip, &len, MTU-40, &ARP_Filter_Dest);
+                     len += ETH_HEADER;
+
                      SeqD = ntohl(tcp->seq);
                      AckD = ntohl(tcp->ack_seq);
                      tcp->seq = htonl(SeqD+ByteSentD);
                      tcp->ack_seq = htonl(AckD-ByteSentS);
                      IPIDD = ntohs(ip->ident);
                      ip->ident = htons(IPIDD+PacketSentD);
-                     data = (char *)((int)tcp + tcp->doff * 4);
-                     datalenD = (int)ip + ntohs(ip->t_len) - (int)data;
+
+                     if (delta == -datalenD && datalenD != 0)     // the packet must be dropped, so we send an ACK
+                     {
+                        char *pck_to_send;
+                        #ifdef DEBUG
+                           Debug_msg("Illithid_ARPBased_GetData -- drop TCP ");
+                        #endif
+                        pck_to_send = ins_pck;
+                        pck_to_send += Inet_Forge_ethernet( pck_to_send, MyMAC, MAC1, ETH_P_IP );
+                        pck_to_send += Inet_Forge_ip( pck_to_send, IP2, IP1, TCP_HEADER, IPIDS+PacketSentS, 0, IPPROTO_TCP);
+                        pck_to_send += Inet_Forge_tcp( pck_to_send, PortDest, PortSource, ntohl(tcp->ack_seq), SeqD+datalenD, TH_ACK, 0, 0);
+
+                        Inet_SendRawPacket(sock, ins_pck, pck_to_send-ins_pck);
+                        PacketSentS++;
+                        ok = 0;  // drop the packet (forwarding is done only if(ok) )
+                     }
+                     ByteSentD += delta;
+
+                     datalenD = (int)ip + ntohs(ip->t_len) - (int)data; // now i store the modified datalen
 
                      ip->checksum = 0;
                      tcp->checksum = 0;
@@ -250,7 +335,25 @@ send:       if (ok) Inet_SendRawPacket(sock, buffer, len);
       else
          usleep(1000);
 
-      nchars = read(pipe_inject_stod[0],tosendchar,MAX_INJECT);
+      nchars = read(pipe_filter_stod[0], &filter, sizeof(DROP_FILTER));
+      if (nchars  == sizeof(DROP_FILTER))
+      {
+         #ifdef DEBUG
+            Debug_msg("Illithid_ARPBased_GetData -- set filter on source [%s][%s]", filter.search, filter.replace);
+         #endif
+         memcpy(&ARP_Filter_Source, &filter, sizeof(DROP_FILTER));
+      }
+
+      nchars = read(pipe_filter_dtos[0], &filter, sizeof(DROP_FILTER));
+      if (nchars == sizeof(DROP_FILTER))
+      {
+         #ifdef DEBUG
+            Debug_msg("Illithid_ARPBased_GetData -- set filter on dest [%s][%s]", filter.search, filter.replace);
+         #endif
+         memcpy(&ARP_Filter_Dest, &filter, sizeof(DROP_FILTER));
+      }
+
+      nchars = read(pipe_inject_stod[0], tosendchar, MAX_INJECT);
       if (nchars > 0)
       {
          char *pck_to_send;
@@ -273,7 +376,7 @@ send:       if (ok) Inet_SendRawPacket(sock, buffer, len);
          PacketSentD++;
       }
 
-      nchars = read(pipe_inject_dtos[0],tosendchar,MAX_INJECT);
+      nchars = read(pipe_inject_dtos[0], tosendchar, MAX_INJECT);
       if (nchars > 0)
       {
          char *pck_to_send;
@@ -294,7 +397,7 @@ send:       if (ok) Inet_SendRawPacket(sock, buffer, len);
          ByteSentS+=nchars;
          PacketSentS++;
       }
-   }
+   }  // end loop
 }
 
 
@@ -410,7 +513,7 @@ void Illithid_GetConnections(short mode, char *iface, char *IP1p, char *IP2p, ch
       memset(buffer, 0, MTU);
 
       len = Inet_GetRawPacket(sock, buffer, MTU, &pkttype);
-      Act_Connection_Mode=Connection_Mode;
+      Act_Connection_Mode = Connection_Mode;
 
       if (len > 0 && ( mode > PUBLICARP || pkttype == PACKET_HOST))
       {
@@ -430,10 +533,10 @@ void Illithid_GetConnections(short mode, char *iface, char *IP1p, char *IP2p, ch
          {
             ip = (IP_header *)(eth+1);
 
-            strcpy(data_to_ettercap.ip_source, inet_ntoa(*(struct in_addr *)&ip->source_ip) );
-            strcpy(data_to_ettercap.ip_dest, inet_ntoa(*(struct in_addr *)&ip->dest_ip) );
-            strcpy(sniff_data_to_ettercap.ip_source, inet_ntoa(*(struct in_addr *)&ip->source_ip) );
-            strcpy(sniff_data_to_ettercap.ip_dest, inet_ntoa(*(struct in_addr *)&ip->dest_ip) );
+            strcpy(data_to_ettercap.ip_source, int_ntoa(ip->source_ip) );
+            strcpy(data_to_ettercap.ip_dest, int_ntoa(ip->dest_ip) );
+            strcpy(sniff_data_to_ettercap.ip_source, int_ntoa(ip->source_ip) );
+            strcpy(sniff_data_to_ettercap.ip_dest, int_ntoa(ip->dest_ip) );
 
             if ( mode == IPBASED && Illithid_ToBeSniffed_ip(IP1p, IP2p, &data_to_ettercap) ) ok1 = 1;
 
@@ -453,7 +556,7 @@ void Illithid_GetConnections(short mode, char *iface, char *IP1p, char *IP2p, ch
                ok1 = 1;
             }
 
-            if (mode == PUBLICARP && !Act_Connection_Mode) ok1=1;
+            if (mode == PUBLICARP && !Act_Connection_Mode) ok1 = 1;
 
             if ( mode == PUBLICARP && !strcmp(data_to_ettercap.ip_dest,IP1p))
             {
@@ -531,7 +634,7 @@ void Illithid_GetConnections(short mode, char *iface, char *IP1p, char *IP2p, ch
 
                if (!( ntohs(ip->frag_and_flags) & IP_OFFMASK))
                {
-                  data =  (char *)((int)udp + UDP_HEADER);
+                  data = (char *)((int)udp + UDP_HEADER);
                   datalen = ntohs(udp->len) - UDP_HEADER;
 
                   if (Act_Connection_Mode)
@@ -570,8 +673,8 @@ int Illithid_ToBeSniffed(char *source, int psource, char *dest, int pdest, SNIFF
 
    if (psource == 0) ps = 1;
    if (pdest == 0) pd = 1;
-   if (!strcmp(source, "")) s = 1;
-   if (!strcmp(dest, "")) d = 1;
+   if (!strcmp(source, "") || !strcmp(source, "0.0.0.0") ) s = 1;
+   if (!strcmp(dest, "") || !strcmp(dest, "0.0.0.0")) d = 1;
 
    if (s || !strcmp(source, data->ip_source))
       if (ps || psource == data->source_port)
