@@ -48,7 +48,7 @@ typedef struct {
    struct host_list *next;
 } host_list;
 
-struct ifreq old_ifr;      	// old iface flags
+struct ifreq old_ifr;         // old iface flags
 #ifdef LINUX
    char IpForward_status[2];  // old ipforward status
 #else
@@ -135,7 +135,6 @@ char * Inet_NameToIp(char *name) // returns ip from hostname
 
 char * Inet_GetMyInfo(char tipo)
 {
-   struct in_addr  to_convert;
    u_long IP_Add, NetMask;
    unsigned char MAC_Add[6];
    static char MAC[18];
@@ -157,8 +156,7 @@ char * Inet_GetMyInfo(char tipo)
    switch (tipo)
    {
          case 0:  // requesting IP
-                  to_convert.s_addr = IP_Add;
-                  sprintf(IP, "%s", inet_ntoa(to_convert));
+                  sprintf(IP, "%s", int_ntoa(IP_Add));
                   return IP;
                   break;
 
@@ -168,8 +166,7 @@ char * Inet_GetMyInfo(char tipo)
                   break;
 
          case 2:  // requesting netmask
-                  to_convert.s_addr = NetMask;
-                  sprintf(MySubnet, "%s", inet_ntoa(to_convert));
+                  sprintf(MySubnet, "%s", int_ntoa(NetMask));
                   return MySubnet;
                   break;
    }
@@ -220,19 +217,20 @@ int Inet_HostInLAN()
    if (Host_In_LAN) free(Host_In_LAN);
    Host_In_LAN = (HOST *)calloc(host_alive,sizeof(HOST));
    if (Host_In_LAN == NULL)
-      Error_msg("ec_Inet:%d calloc() | ERRNO : %d | %s", __LINE__, errno, sys_errlist[errno]);
+      Error_msg("ec_Inet:%d calloc() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
    index = list;
    for( ; index; index = (host_list *)index->next)
    {
-      struct in_addr to_convert;
-      to_convert.s_addr = index->IP_Add;
-      sprintf(Host_In_LAN[k].ip,"%s",inet_ntoa(to_convert));
+      sprintf(Host_In_LAN[k].ip,"%s",int_ntoa(index->IP_Add));
       snprintf(Host_In_LAN[k].name, 128, "%s", Inet_HostName(Host_In_LAN[k].ip));
       Inet_PutMACinString(Host_In_LAN[k].mac, index->MAC_Add);
       k++;
    }
    Inet_Free_list(list);
+#ifdef DEBUG
+   Debug_msg("Inet_HostInLAN -- %d hosts in the lan", host_alive);
+#endif
    return host_alive;
 }
 
@@ -264,7 +262,7 @@ host_list *Inet_Host_in_LAN_list(char *interface)
 
    head = (host_list *)malloc(sizeof(host_list));
    if (head == NULL)
-         Error_msg("ec_Inet:%d malloc() | ERRNO : %d | %s", __LINE__, errno, sys_errlist[errno]);
+         Error_msg("ec_Inet:%d malloc() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
    head->next = NULL;
 
@@ -280,55 +278,55 @@ host_list *Inet_Host_in_LAN_list(char *interface)
    Debug_msg("Inet_HostInLAN_list -- netmask 0x%0x  hosts %d", NetMask, N_hosts);
 #endif
 
-	if (Options.broadping)
-	{
+   if (Options.broadping)
+   {
 
-		   BroadAdd = head->IP_Add | (~NetMask);
-   		buf = Inet_Forge_packet( ETH_HEADER + IP_HEADER + ICMP_HEADER );
-   		Inet_Forge_ethernet( buf, head->MAC_Add, ETH_BROADCAST, ETH_P_IP );
+         BroadAdd = head->IP_Add | (~NetMask);
+         buf = Inet_Forge_packet( ETH_HEADER + IP_HEADER + ICMP_HEADER );
+         Inet_Forge_ethernet( buf, head->MAC_Add, ETH_BROADCAST, ETH_P_IP );
 
-   		Inet_Forge_ip( buf + ETH_HEADER,
-   		               head->IP_Add,
-   		               BroadAdd,
-   		               sizeof(ICMP_header),
-   		               0xe77e,
-   		               0,
-   		               IPPROTO_ICMP );
+         Inet_Forge_ip( buf + ETH_HEADER,
+                        head->IP_Add,
+                        BroadAdd,
+                        sizeof(ICMP_header),
+                        0xe77e,
+                        0,
+                        IPPROTO_ICMP );
 
-   		Inet_Forge_icmp( buf + ETH_HEADER + IP_HEADER, ICMP_ECHO, 0, NULL, 0 );
-   		Inet_SendRawPacket(sock, buf, ETH_HEADER + IP_HEADER + ICMP_HEADER);
-   		Inet_Forge_packet_destroy( buf );
+         Inet_Forge_icmp( buf + ETH_HEADER + IP_HEADER, ICMP_ECHO, 0, NULL, 0 );
+         Inet_SendRawPacket(sock, buf, ETH_HEADER + IP_HEADER + ICMP_HEADER);
+         Inet_Forge_packet_destroy( buf );
 
-	}
-	else // !broadping
-	{
+   }
+   else // !broadping
+   {
 
-   		buf = Inet_Forge_packet( ETH_HEADER + ARP_HEADER );
+         buf = Inet_Forge_packet( ETH_HEADER + ARP_HEADER );
 
-   		// frame ethernet header
-   		Inet_Forge_ethernet( buf, head->MAC_Add, ETH_BROADCAST, ETH_P_ARP );
+         // frame ethernet header
+         Inet_Forge_ethernet( buf, head->MAC_Add, ETH_BROADCAST, ETH_P_ARP );
 
-   		for (index=1; index<=N_hosts; index++)
-   		{
-   		   int dest_ip;
-   		   dest_ip = (head->IP_Add&NetMask)|htonl(index);
+         for (index=1; index<=N_hosts; index++)
+         {
+            int dest_ip;
+            dest_ip = (head->IP_Add&NetMask)|htonl(index);
 
-   		   // if dest is equal to me
-   		   if (dest_ip != head->IP_Add)
-   		   {
-   		      // arp request
-   		      Inet_Forge_arp( buf+ETH_HEADER, ARPOP_REQUEST,
-   		                      head->MAC_Add, head->IP_Add,
-   		                      ARP_BROADCAST, dest_ip );
+            // if dest is equal to me
+            if (dest_ip != head->IP_Add)
+            {
+               // arp request
+               Inet_Forge_arp( buf+ETH_HEADER, ARPOP_REQUEST,
+                               head->MAC_Add, head->IP_Add,
+                               ARP_BROADCAST, dest_ip );
 
-   		      Inet_SendRawPacket(sock, buf, ETH_HEADER + ARP_HEADER);
-   		   }
-   		   usleep(500);
-   		}
+               Inet_SendRawPacket(sock, buf, ETH_HEADER + ARP_HEADER);
+            }
+            usleep(500);
+         }
 
-   		Inet_Forge_packet_destroy( buf );
+         Inet_Forge_packet_destroy( buf );
 
-	}
+   }
 
 #ifdef DEBUG
    Debug_msg("Inet_HostInLAN_list -- listening for replies...");
@@ -340,90 +338,90 @@ host_list *Inet_Host_in_LAN_list(char *interface)
 
    buf = Inet_Forge_packet( MTU );
 
-	if (Options.broadping)
-	{
-			do
-   		{
-   		   short pkttype;
-   		   int len;
-   		   host_list **index;
-   		   ETH_header *HEther;
-   		   IP_header *HIP;
+   if (Options.broadping)
+   {
+         do
+         {
+            short pkttype;
+            int len;
+            host_list **index;
+            ETH_header *HEther;
+            IP_header *HIP;
 
-   		   TIME_FINISH;
+            TIME_FINISH;
 
-   		   len = Inet_GetRawPacket(sock, buf, MTU, &pkttype);
+            len = Inet_GetRawPacket(sock, buf, MTU, &pkttype);
 
-   		   if (len > 0 && pkttype == PACKET_HOST)
-   		   {
-   		      HEther = (ETH_header *) buf;
-   		      if ( ntohs(HEther->type) == ETH_P_IP )
-   		      {
-   		         HIP = (IP_header *)(HEther + 1);
-   		         if (HIP->proto != IPPROTO_ICMP) continue;
-   		         index = &head;
+            if (len > 0 && pkttype == PACKET_HOST)
+            {
+               HEther = (ETH_header *) buf;
+               if ( ntohs(HEther->type) == ETH_P_IP )
+               {
+                  HIP = (IP_header *)(HEther + 1);
+                  if (HIP->proto != IPPROTO_ICMP) continue;
+                  index = &head;
 
-						#ifdef DEBUG
-						   Debug_msg("Inet_HostInLAN_list -- got a reply after %.5f seconds", TIME_ELAPSED );
-						#endif
+                  #ifdef DEBUG
+                     Debug_msg("Inet_HostInLAN_list -- got a reply after %.5f seconds", TIME_ELAPSED );
+                  #endif
 
-   		         while(*index != NULL && memcmp(&((*index)->IP_Add),&HIP->source_ip,4))
-   		     			index = (host_list **)&((*index)->next);
+                  while(*index != NULL && memcmp(&((*index)->IP_Add),&HIP->source_ip,4))
+                     index = (host_list **)&((*index)->next);
 
-   		         if (*index == NULL)
-   		         {
-   		 				if ( (*index = (host_list *)malloc(sizeof(host_list))) == NULL)
-   		                Error_msg("ec_inet:%d malloc() | ERRNO : %d | %s", __LINE__, errno, sys_errlist[errno]);
-   		     			(*index)->next = NULL;
-   		     			memcpy((*index)->MAC_Add, HEther->source_mac, 6);
-   		     			memcpy((char *)&((*index)->IP_Add), &HIP->source_ip, 4);
-   		         }
-   		      }
-   		   }
-   		} while ( TIME_ELAPSED < 1 );
+                  if (*index == NULL)
+                  {
+                     if ( (*index = (host_list *)malloc(sizeof(host_list))) == NULL)
+                         Error_msg("ec_inet:%d malloc() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+                     (*index)->next = NULL;
+                     memcpy((*index)->MAC_Add, HEther->source_mac, 6);
+                     memcpy((char *)&((*index)->IP_Add), &HIP->source_ip, 4);
+                  }
+               }
+            }
+         } while ( TIME_ELAPSED < 1 );
 
-	}
-	else	// !broadping
-	{
+   }
+   else  // !broadping
+   {
 
-   		do
-   		{
-   		   int leng = 0;
-   		   short pkttype;
-   		   host_list **index;
-   		   ETH_header *ethpkt;
-   		   ARP_header *arppkt;
+         do
+         {
+            int leng = 0;
+            short pkttype;
+            host_list **index;
+            ETH_header *ethpkt;
+            ARP_header *arppkt;
 
-   		   leng = Inet_GetRawPacket(sock, buf, MTU, &pkttype);
+            leng = Inet_GetRawPacket(sock, buf, MTU, &pkttype);
 
-   		   ethpkt = (ETH_header *)buf;
-   		   arppkt = (ARP_header *)(buf + ETH_HEADER);
+            ethpkt = (ETH_header *)buf;
+            arppkt = (ARP_header *)(buf + ETH_HEADER);
 
-   		   TIME_FINISH;
+            TIME_FINISH;
 
-   		   if (leng > 0 && pkttype == PACKET_HOST && ethpkt->type == htons(ETH_P_ARP) && arppkt->opcode == htons(ARPOP_REPLY))
-   		   {
-   		      index = &head;
+            if (leng > 0 && pkttype == PACKET_HOST && ethpkt->type == htons(ETH_P_ARP) && arppkt->opcode == htons(ARPOP_REPLY))
+            {
+               index = &head;
 
-					#ifdef DEBUG
-					   Debug_msg("Inet_HostInLAN_list -- got a reply after %.5f seconds", TIME_ELAPSED );
-					#endif
+               #ifdef DEBUG
+                  Debug_msg("Inet_HostInLAN_list -- got a reply after %.5f seconds", TIME_ELAPSED );
+               #endif
 
-   		      while(*index != NULL && memcmp(&((*index)->IP_Add),arppkt->source_ip,4))
-   		         index = (host_list **)&((*index)->next);
+               while(*index != NULL && memcmp(&((*index)->IP_Add),arppkt->source_ip,4))
+                  index = (host_list **)&((*index)->next);
 
-   		      if (*index == NULL)
-   		      {
-   		         if ( (*index = (host_list *)malloc(sizeof(host_list))) == NULL)
-   		            Error_msg("ec_inet:%d malloc() | ERRNO : %d | %s", __LINE__, errno, sys_errlist[errno]);
-   		         (*index)->next = NULL;
-   		         memcpy((*index)->MAC_Add, arppkt->source_add, 6);
-   		         memcpy((char *)&((*index)->IP_Add), arppkt->source_ip, 4);
-   		      }
-   		   }
-   		} while ( TIME_ELAPSED < 1.5 );
+               if (*index == NULL)
+               {
+                  if ( (*index = (host_list *)malloc(sizeof(host_list))) == NULL)
+                     Error_msg("ec_inet:%d malloc() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+                  (*index)->next = NULL;
+                  memcpy((*index)->MAC_Add, arppkt->source_add, 6);
+                  memcpy((char *)&((*index)->IP_Add), arppkt->source_ip, 4);
+               }
+            }
+         } while ( TIME_ELAPSED < 1.5 );
 
-	}
+   }
 
    Inet_Forge_packet_destroy( buf );
    close(sock);
@@ -431,7 +429,6 @@ host_list *Inet_Host_in_LAN_list(char *interface)
 }
 
 
-
 SniffingHost *Inet_NoSniff(void)
 {
    static SniffingHost *SniffTable=NULL;
@@ -446,8 +443,8 @@ SniffingHost *Inet_NoSniff(void)
 #endif
 
    if (SniffTable) free (SniffTable);
-   SniffTable = calloc(number_of_hosts_in_lan, sizeof(SniffingHost));
-   memset(SniffTable,0,sizeof(SniffingHost)*number_of_hosts_in_lan);
+   SniffTable = calloc(number_of_hosts_in_lan * 100, sizeof(SniffingHost));
+   memset(SniffTable, 0, sizeof(SniffingHost)*number_of_hosts_in_lan);
 
    sock = Inet_OpenRawSock(Options.netiface);
 
@@ -457,7 +454,7 @@ SniffingHost *Inet_NoSniff(void)
 
    for (i=0; i<number_of_hosts_in_lan; i++)
    {
-      if (inet_addr(Inet_MyIPAddress()) != inet_addr(Host_In_LAN[i].ip))
+      if (inet_addr(Host_In_LAN[0].ip) != inet_addr(Host_In_LAN[i].ip))
       {
          char MyMAC[6];
          char DestMAC[6];
@@ -539,6 +536,10 @@ SniffingHost *Inet_NoSniff(void)
       }
    } while ( TIME_ELAPSED < 3 );
 
+#ifdef DEBUG
+   Debug_msg("Inet_NoSniff -- analyzing results" );
+#endif
+
    // Search for strange ARP entries
    for (i=0; i<number_of_hosts_in_lan-1; i++)
       for(j=i+1; j<number_of_hosts_in_lan; j++)
@@ -550,6 +551,10 @@ SniffingHost *Inet_NoSniff(void)
             SniffTableIndex++;
          }
 
+#ifdef DEBUG
+   Debug_msg("Inet_NoSniff -- freeing buffer" );
+#endif
+
    Inet_Forge_packet_destroy( buf );
 
    close(sock);
@@ -588,6 +593,11 @@ int Inet_Fake_Host()
 int Inet_CheckSwitch()
 {
    int link_type=2;
+
+#ifdef DEBUG
+   Debug_msg("Inet_CheckSwitch" );
+#endif
+
    if (number_of_hosts_in_lan>1)
    {
        int fakeip,destip,sock,MTU,i;
@@ -615,8 +625,8 @@ int Inet_CheckSwitch()
 
        Inet_Forge_ethernet( buf, MyMAC, DestMAC, ETH_P_ARP );
        Inet_Forge_arp( buf+ETH_HEADER, ARPOP_REPLY,
-                   	  DestMAC, fakeip,
-                   	  DestMAC, destip );
+                       DestMAC, fakeip,
+                       DestMAC, destip );
        for(i=0; i<5; i++)
        {
            usleep(1000);
@@ -631,23 +641,28 @@ int Inet_CheckSwitch()
            len=Inet_GetRawPacket(sock,buf,MTU,&type);
            TIME_FINISH;
 
-	   		if (len>0)
-	   		{
-	       		ETH_header *eth;
-	       		eth=(ETH_header *)buf;
-	       		if (!memcmp(DestMAC,eth->dest_mac,6))
-	       		{
-	      			link_type=1;
-		   			break;
-	       		}
-	   		}
-			}while(TIME_ELAPSED<1);
+            if (len>0)
+            {
+               ETH_header *eth;
+               eth=(ETH_header *)buf;
+               if (!memcmp(DestMAC,eth->dest_mac,6))
+               {
+                  link_type=1;
+                  break;
+               }
+            }
+         }while(TIME_ELAPSED<1);
 
        free(buf);
        close(sock);
    }
    else return 0;
    Inet_Restore_ifr();
+
+#ifdef DEBUG
+   Debug_msg("Inet_CheckSwitch -- type %d", link_type );
+#endif
+
    return link_type;
 }
 
