@@ -56,7 +56,7 @@ u_char * Inet_Forge_packet( u_short size )
 
    buf = (u_char *)calloc(size+50, sizeof(u_char));
    if (buf == NULL)
-      Error_msg("ec_Inet_Forge:%d calloc() | ERRNO : %d | %s", __LINE__, errno, sys_errlist[errno]);
+      Error_msg("ec_Inet_Forge:%d calloc() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
    return (buf);
 }
