@@ -847,6 +847,7 @@ void Interface_CheckForPoisoner(void)
    if (!found)
       Interface_PopUp("No poisoners found in this lan (seems to be safe)");
 
+   free(SniffList);
    delwin(message_window);
    touchwin(main_window);
    wnoutrefresh(main_window);
@@ -918,14 +919,14 @@ void Interface_FingerPrint(void)
    wattroff(finger_win, A_BOLD);
    wbkgdset(finger_win, COLOR_PAIR(BOTTOM_COLOR));
 
-	if (strcmp(long_os_fingers, ""))
-   	strncpy(temp, strtok(long_os_fingers, "\n"), W_MAINX2-4-18);
+   if (strcmp(long_os_fingers, ""))
+      strncpy(temp, strtok(long_os_fingers, "\n"), W_MAINX2-4-18);
 
    mvwprintw(finger_win, 2, 20, "%s", temp);
    for(i=0; i<j-1 ;i++)
    {
-   	memset(temp, 0, 100);
-   	strncpy(temp, strtok(NULL, "\n"), W_MAINX2-4-18);
+      memset(temp, 0, 100);
+      strncpy(temp, strtok(NULL, "\n"), W_MAINX2-4-18);
       mvwprintw(finger_win, 3+i, 20, "%s", temp);
    }
    mvwprintw(finger_win, dimY-3, 20, "%s", mac_finger);
@@ -1053,7 +1054,9 @@ void Interface_Run(void)
                         "[return]  - select the IP",
                         "[space]   - wipe/deselect the IPs",
                         "[tab]     - switch between source and dest",
-                        "[aA]      - ARP posoning based sniffing (for switched LAN)",
+                        "[aA]      - ARP posoning based sniffing ",
+                        "             . for sniffing on switched LAN",
+                        "             . for man-in-the-middle technique",
                         "[sS]      - IP based sniffing",
                         "[mM]      - MAC based sniffing",
 #ifdef PERMIT_PLUGINS
