@@ -516,7 +516,7 @@ void Interface_Sniff_Run(short mode)
                      if (mode == ARPBASED)
                      {
                         kill(Illithid_pid, SIGUSR1);  // activate/deactivate special dissector
-                        active_dissector = 0;
+                        kill(getpid(), SIGUSR1);
                         Interface_Sniff_ActiveDissecor(mode);
                      }
                      else
