@@ -57,8 +57,8 @@
 #define KEY_RETURN   10
 #define KEY_CTRL_L   12
 
-#define ASCII_VIEW      0        // data in the sniffing windows...
-#define HEX_VIEW        1
+#define ASCII_VIEW   0        // data in the sniffing windows...
+#define HEX_VIEW     1
 
 
 // protos...
@@ -67,17 +67,19 @@ void Interface_Sniff_Data_Run(char *ipsource, int portsource, char *ipdest, int
 void Interface_Sniff_Data_Redraw(void);
 void Interface_Sniff_Data_KeyTab(char *ipsource, int portsource, char *ipdest, int portdest);
 void Interface_Sniff_Data_SniffData(char *source, char *dest, int portsource, int portdest, char proto);
-void Interface_Sniff_Data_LogToFile(char *ipsource, int portsource, char *ipdest, int portdest);
+void Interface_Sniff_Data_LogToFile(char proto, char *ipsource, int portsource, char *ipdest, int portdest);
 void Interface_Sniff_Data_Winch(void);
 void Interface_Sniff_Data_StopCont(void);
 void Interface_Sniff_Data_View(short mode);
 void Interface_Sniff_Data_Scroll(short direction);
 void Interface_Sniff_Data_DrawScroller(void);
 void Interface_Sniff_Data_Inject(char proto, char *app);
+void Interface_Sniff_Data_Filter(void);
+void Interface_Sniff_Data_ActiveFilter(short mode);
 
 // global variables
 
-extern WINDOW *main_window, *bottom_window;
+extern WINDOW *main_window, *bottom_window, *top_window;
 WINDOW *data_source_win, *data_dest_win, *data_source, *data_dest;
 WINDOW *win_pointer;
 
@@ -186,7 +188,7 @@ void Interface_Sniff_Data_KeyTab(char *ipsource, int portsource, char *ipdest, i
 
 
 
-void Interface_Sniff_Data_LogToFile(char *ipsource, int portsource, char *ipdest, int portdest)
+void Interface_Sniff_Data_LogToFile(char proto, char *ipsource, int portsource, char *ipdest, int portdest)
 {
    WINDOW *question_window;
    char question[100];
@@ -208,12 +210,12 @@ void Interface_Sniff_Data_LogToFile(char *ipsource, int portsource, char *ipdest
    if (win_pointer == data_source_win)
    {
       strcpy(question, "Do U want to log SOURCE-to-DEST to this file ? (y/n)");
-      sprintf(filename, "%s-%s:%d-%s:%d.log", date, ipsource, portsource, ipdest, portdest);
+      sprintf(filename, "%s-%c-%s:%d-%s:%d.log", date, proto, ipsource, portsource, ipdest, portdest);
    }
    else
    {
       strcpy(question, "Do U want to log DEST-to-SOURCE to this file ? (y/n)");
-      sprintf(filename, "%s-%s:%d-%s:%d.log", date, ipdest, portdest, ipsource, portsource);
+      sprintf(filename, "%s-%c-%s:%d-%s:%d.log", date, proto, ipdest, portdest, ipsource, portsource);
    }
 
    question_window = newwin(7, strlen(question) + 4,0,0);
@@ -226,7 +228,7 @@ void Interface_Sniff_Data_LogToFile(char *ipsource, int portsource, char *ipdest
    doupdate();
 
    wbkgdset(question_window, COLOR_PAIR(HELP_COLOR));
-   mvwprintw(question_window,  4, 7, filename);
+   mvwprintw(question_window,  4, 4, filename);
    answer = wgetch(question_window);
    delwin(question_window);
 
@@ -536,6 +538,100 @@ void Interface_Sniff_Data_Inject(char proto, char *app)
 }
 
 
+void Interface_Sniff_Data_Filter(void)
+{
+
+   char answer;
+   DROP_FILTER filter;
+   DROP_FILTER null_filter;
+
+#ifdef DEBUG
+   Debug_msg("Interface_Sniff_Data_Filter %d", inject);
+#endif
+
+
+   if (inject <= 0)  // 0 no inject  -1 no first packet
+   {
+      answer = Interface_PopUp("Do U really want to set up a filter on this connection (y/n)?");
+      Interface_Sniff_Data_Redraw();
+      if ((answer != 'y') && (answer != 'Y'))
+         return;
+   }
+
+   memset(&filter, 0, sizeof(DROP_FILTER));
+   memset(&null_filter, 0, sizeof(DROP_FILTER));
+
+   if (Interface_Inject_Filter(&filter))
+   {
+      if (filter.slen == 0 && memcmp(&filter, &null_filter, sizeof(DROP_FILTER)) )
+      {
+         Interface_PopUp("Setting a 0 length search string is NOT a good idea... ;)");
+         Interface_Sniff_Data_Redraw();
+         return;
+      }
+
+      if (win_pointer == data_dest_win)
+      {
+         #ifdef DEBUG
+            Debug_msg("Interface_Sniff_Data_Filter -- set filter on source [%s]", filter.search);
+         #endif
+         write(pipe_filter_stod[1], &filter, sizeof(DROP_FILTER));
+         memcpy(&ARP_Filter_Source, &filter,  sizeof(DROP_FILTER));
+      }
+      else
+      {
+         #ifdef DEBUG
+            Debug_msg("Interface_Sniff_Data_Filter -- set filter on dest [%s]", filter.search);
+         #endif
+         write(pipe_filter_dtos[1], &filter, sizeof(DROP_FILTER));
+         memcpy(&ARP_Filter_Dest, &filter,  sizeof(DROP_FILTER));
+      }
+
+      if ( !memcmp(&ARP_Filter_Source, &null_filter, sizeof(DROP_FILTER)) && !memcmp(&ARP_Filter_Dest, &null_filter, sizeof(DROP_FILTER)) )
+         Interface_Sniff_Data_ActiveFilter(0);
+      else
+      {
+         Interface_Sniff_Data_ActiveFilter(1);
+         inject = 1;  // on exit the connection must be RSTted
+      }
+   }
+
+   Interface_Sniff_Data_Redraw();
+
+   wnoutrefresh(bottom_window);
+
+   doupdate();
+
+}
+
+
+void Interface_Sniff_Data_ActiveFilter(short mode)
+{
+
+#ifdef DEBUG
+   Debug_msg("Interface_Sniff_Data_ActiveFilter %d", mode);
+#endif
+
+   wbkgdset(top_window, COLOR_PAIR(HELP_COLOR));
+   mvwprintw(top_window, 2, 55, "Active Filter: ");
+
+   switch(mode)
+   {
+      case 1:  wbkgdset(top_window, COLOR_PAIR(BOTTOM_COLOR));
+               mvwprintw(top_window, 2, 70, "ON ");
+               break;
+
+      case 0:  wbkgdset(top_window, COLOR_PAIR(BOTTOM_COLOR));
+               mvwprintw(top_window, 2, 70, "OFF");
+               break;
+   }
+
+   wnoutrefresh(top_window);
+   doupdate();
+
+}
+
+
 
 void Interface_Sniff_Data_Run(char *ipsource, int portsource, char *ipdest, int portdest, char *macsource, char *macdest, char proto, char *app, short mode)
 {
@@ -550,11 +646,16 @@ void Interface_Sniff_Data_Run(char *ipsource, int portsource, char *ipdest, int
 
    pipe(pipe_inject_stod);
    pipe(pipe_inject_dtos);
+   pipe(pipe_filter_stod);
+   pipe(pipe_filter_dtos);
 
-   if ( mode <= PUBLICARP )	// PUBLICARP or ARPBASED
+   if ( mode <= PUBLICARP )   // PUBLICARP or ARPBASED
    {
       if ( mode == PUBLICARP )
+      {
          dopple_pid = Doppleganger_Run(Options.netiface, ipsource, ipdest, macsource, macdest);
+         mode = ARPBASED;
+      }
 
       Illithid_data_pid = Illithid_ARPBased_GetData(Options.netiface, proto, ipsource, portsource, ipdest, portdest, macsource, macdest);
    }
@@ -595,6 +696,7 @@ void Interface_Sniff_Data_Run(char *ipsource, int portsource, char *ipdest, int
 
    wbkgdset(main_window, COLOR_PAIR(MAIN_COLOR));
 
+   Interface_Sniff_Data_ActiveFilter(0);
    Interface_Sniff_Data_DrawScroller();
 
    werase(main_window);
@@ -667,7 +769,7 @@ void Interface_Sniff_Data_Run(char *ipsource, int portsource, char *ipdest, int
 
             case 'L':
             case 'l':
-                  Interface_Sniff_Data_LogToFile(ipsource, portsource, ipdest, portdest);
+                  Interface_Sniff_Data_LogToFile(proto, ipsource, portsource, ipdest, portdest);
                   break;
 
             case 'A':
@@ -699,7 +801,26 @@ void Interface_Sniff_Data_Run(char *ipsource, int portsource, char *ipdest, int
                   }
                   else
                   {
-                     Interface_PopUp("Characters injection only supported in ARP Based mode !!");
+                     Interface_PopUp("Characters injection is only supported in ARP Based mode !!");
+                     Interface_Sniff_Data_Redraw();
+                  }
+                  break;
+
+            case 'F':
+            case 'f':
+                  if ( mode == ARPBASED )
+                  {
+                     if (strstr(app, "ssh") || strstr(app, "SSH"))
+                     {
+                        Interface_PopUp("You CAN'T filter a crypted connection !!");
+                        Interface_Sniff_Data_Redraw();
+                     }
+                     else
+                        Interface_Sniff_Data_Filter();
+                  }
+                  else
+                  {
+                     Interface_PopUp("Filtering is only supported in ARP Based mode !!");
                      Interface_Sniff_Data_Redraw();
                   }
                   break;
@@ -721,6 +842,7 @@ void Interface_Sniff_Data_Run(char *ipsource, int portsource, char *ipdest, int
                         "[pgUp]    - scroll back (as well as UpArrow)",
                         "[pgDw]    - scroll forward (as well as DownArrow)",
                         "[iI]      - inject characters in the connection",
+                        "[fF]      - filter (search for, and replace or drop) packets",
                         "[aA]      - ASCII view",
                         "[xX]      - HEX view",
                         "[sS]      - stop/cont the sniff (only visualization)",
@@ -755,10 +877,14 @@ void Interface_Sniff_Data_Run(char *ipsource, int portsource, char *ipdest, int
                      delwin(data_source_win);
                      data_source_win = NULL;    // for winching (see ec_signal.c)
                      wbkgdset(bottom_window, COLOR_PAIR(BOTTOM_COLOR));
+                     mvwhline(top_window, 2, 55, ' ', 20);
+                     memset(&ARP_Filter_Source, 0, sizeof(DROP_FILTER));
+                     memset(&ARP_Filter_Dest, 0, sizeof(DROP_FILTER));
                      delwin(data_dest_win);
                      delwin(data_source);
                      delwin(data_dest);
                      werase(bottom_window);
+                     wnoutrefresh(top_window);
                      wnoutrefresh(bottom_window);
                      wnoutrefresh(main_window);
                      doupdate();
