@@ -18,25 +18,26 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
+#include "include/ec_main.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
 #include <sys/ioctl.h>
-
-
-#include "include/ec_main.h"
-#include "include/ec_error.h"
-#include "include/ec_inet.h"
-#include "include/ec_simple.h"
-#include "include/ec_signal.h"
-
+#include <errno.h>
 #ifdef HAVE_GETOPT_H
 	#include <getopt.h>
 #else
 	#include "missing/getopt.h"
 #endif
 
+
+#include "include/ec_error.h"
+#include "include/ec_inet.h"
+#include "include/ec_simple.h"
+#include "include/ec_signal.h"
+
 #ifdef HAVE_NCURSES
     #include "include/ec_interface.h"
 #endif
@@ -66,6 +67,8 @@ int pipe_with_illithid;
 int pipe_with_illithid_data;
 int pipe_inject_stod[2];
 int pipe_inject_dtos[2];
+int pipe_filter_stod[2];
+int pipe_filter_dtos[2];
 
 char active_dissector = 1;    // ec_main.h
 
@@ -76,6 +79,7 @@ void Main_Interactive(void);
 void Main_Normal(void);
 void Main_CheckForRun(void);
 void Main_ParseParameters(char *first, char *second, char *third, char *fourth);
+void Main_Devel_Release(void);
 
 //-----------------------------------
 
@@ -103,6 +107,8 @@ int main(int argc, char *argv[])
       { "linktype", no_argument, NULL, 't' },
       { "collect", no_argument, NULL, 'C' },
       { "broadping", no_argument, NULL, 'b' },
+      { "logtofile", no_argument, NULL, 'L' },
+      { "quiet", no_argument, NULL, 'q' },
       { 0 , 0 , 0 , 0}
    };
 
@@ -118,12 +124,15 @@ int main(int argc, char *argv[])
 
    Signal_SigBuster();     // signal masking
 
+#if DEVEL_RELEASE == 1
+	Main_Devel_Release();
+#endif
 
 
 #ifdef PERMIT_PLUGINS
-   while ((c = getopt_long (argc, argv, "hvNlasmci:p:xzuftCbn:",long_options, (int *)0)) != EOF) {
+   while ((c = getopt_long (argc, argv, "hvNlasmci:p:xzuftCbn:Lq",long_options, (int *)0)) != EOF) {
 #else
-   while ((c = getopt_long (argc, argv, "hvNlasmci:xzuftCbn:",long_options, (int *)0)) != EOF) {    // no plugin
+   while ((c = getopt_long (argc, argv, "hvNlasmci:xzuftCbn:Lq",long_options, (int *)0)) != EOF) {    // no plugin
 #endif
 
       switch (c) {
@@ -161,7 +170,11 @@ int main(int argc, char *argv[])
 
          case 'C':   Options.collect = 1;    break;
 
-         case 'b':   Options.broadping = 1;    break;
+         case 'b':   Options.broadping = 1;  break;
+
+         case 'L':   Options.logtofile = 1;  break;
+
+         case 'q':   Options.quiet = 1;      break;
 
 #ifdef PERMIT_PLUGINS
          case 'p':
@@ -196,7 +209,11 @@ int main(int argc, char *argv[])
          Error_msg("No suitable Network Interface found !!");
 
    if ( Inet_CorrectIface(Options.netiface) < 0)
+#ifdef LINUX
+   	Error_msg("%s (%s)", strerror(errno), Options.netiface);
+#else
       Error_msg("Network Interface %s is invalid !!", Options.netiface);
+#endif
 
 
    if (Options.normal)
@@ -236,8 +253,10 @@ void Main_Usage(void)
    fprintf (stdout, "  -f, --fingerprint HOST       do OS fingerprinting on HOST\n\n");
    fprintf (stdout, "  -C, --collect                collect users and passwords only\n");
    fprintf (stdout, "                               this options must be used with a sniffing method\n");
-   fprintf (stdout, "                                    Es: ettercap -NCzs\n\n");
+   fprintf (stdout, "                                    Eg: ettercap -NCzs\n\n");
    fprintf (stdout, "  -x, --hexview                display data in hex mode\n\n");
+   fprintf (stdout, "  -L, --logtofile              logs all data to specific file(s)\n\n");
+   fprintf (stdout, "  -q, --quiet                  \"demonize\" ettercap (useful with -L)\n\n");
    fprintf (stdout, "  -i, --iface IFACE            network interface to be used\n\n");
    fprintf (stdout, "  -n, --netmask NETMASK        the netmask used to scan the lan\n\n");
    fprintf (stdout, "  -c, --check                  check for other poisoners in the LAN\n\n");
@@ -266,7 +285,8 @@ void Main_Interactive(void)
 
 #ifdef HAVE_NCURSES
 
-   ioctl(0, TIOCGWINSZ, &ws);          // syscall for the window size
+   if ( ioctl(0, TIOCGWINSZ, &ws) < 0)          // syscall for the window size
+   	Error_msg("ec_main:%d ioctl(TIOCGWINSZ) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
    if ( (ws.ws_row < 25) || (ws.ws_col < 80) )
       Error_msg("Screen must be at least 25x80 !!");
@@ -355,6 +375,9 @@ void Main_CheckForRun(void)
       Error_msg("Sorry UID %d, must be root to run %s !!", getuid(), PROGRAM);
 #endif
 
+	if (!strstr(program_argv0, PROGRAM))		// just for script-kiddies ;)
+		Error_msg("ehi guy ! my name is \"%s\" ! I really don't like \"%s\"...", PROGRAM, program_argv0);
+
 }
 
 
@@ -368,10 +391,12 @@ void Main_ParseParameters(char *first, char *second, char *third, char *fourth)
 
 #define R(a,b,c) (a & b) | ((a ^ b) & c)     // returns true if more than one was selected
 
+	if (Options.quiet && !Options.normal && !Options.logtofile )
+		Error_msg("Demonization is only useful with -NL or -NLC !!\n\n");
+
    if ( R(Options.arpsniff, Options.sniff, Options.macsniff) )
       Error_msg("Please select only one sniffing method !!\n\n");
 
-
    if (Options.silent && Options.broadping)
       Error_msg("Please select only one start up method !!\n\n");
 
@@ -426,6 +451,13 @@ void Main_ParseParameters(char *first, char *second, char *third, char *fourth)
          {
             sscanf(first, "%128[^:]:%d", Host_Dest.name, &Host_Dest.port);
             if (second) sscanf(second, "%128[^:]:%d", Host_Source.name, &Host_Source.port);
+
+            if (!strcasecmp(Host_Source.name, "ANY") || !strcmp(Host_Source.name, "0") )
+            	strcpy(Host_Source.name, "");
+
+            if (!strcasecmp(Host_Dest.name, "ANY") || !strcmp(Host_Dest.name, "0") )
+            	strcpy(Host_Dest.name, "");
+
          }
       }
 
@@ -457,9 +489,28 @@ void Main_ParseParameters(char *first, char *second, char *third, char *fourth)
 #ifdef DEBUG
    Debug_msg("Main_ParseParameters - name - [%s][%s]", Host_Dest.name, Host_Source.name);
    Debug_msg("Main_ParseParameters -  IP  - [%s][%s]", Host_Dest.ip, Host_Source.ip);
+   Debug_msg("Main_ParseParameters - port - [%d][%d]", Host_Dest.port, Host_Source.port);
    Debug_msg("Main_ParseParameters -  MAC - [%s][%s]", Host_Dest.mac, Host_Source.mac);
 #endif
 
 }
 
+void Main_Devel_Release(void)
+{
+
+	fprintf (stdout, "\n\n");
+	fprintf (stdout, "  %s %s IS STILL IN DEVELOPMENT STATE. ABSOLUTELY NO WARRANTY !\n\n", PROGRAM, VERSION);
+	fprintf (stdout, "  if you are a betatester please report bugs to :\n");
+	fprintf (stdout, "      http://ettercap.sourceforge.net/forum/viewforum.php?forum=7\n");
+	fprintf (stdout, "  or send an email to:\n");
+	fprintf (stdout, "      alor@users.sourceforge.net\n");
+	fprintf (stdout, "      crwm@freemail.it\n\n");
+	fprintf (stdout, "  if you are NOT a betatester, I don't know where you downloaded this release\n");
+	fprintf (stdout, "  but this is NOT for you, so don't blame us for any bugs or problems !\n");
+	fprintf (stdout, "\n\n");
+
+}
+
 /* EOF */
+
+
