@@ -17,13 +17,17 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
+#include "include/ec_main.h"
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
 #include <signal.h>
+#include <unistd.h>
+#ifdef LINUX
+	#define __USE_GNU		// for strsignal()
+#endif
+#include <string.h>
 
-#include "include/ec_main.h"
 
 #ifdef HAVE_NCURSES
    #include <ncurses.h>
@@ -65,7 +69,7 @@ void Signal_SigBuster()
    signal(SIGUSR2, Signal_USR2);
 }
 
-void Signal_SEGV(int sig)
+RETSIGTYPE Signal_SEGV(int sig)
 {
 #ifdef DEBUG
    Debug_msg("[%s] Segmentation Fault...", program_argv0 );
@@ -82,30 +86,30 @@ void Signal_SEGV(int sig)
 }
 
 
-void Signal_TERM(int sig)
+RETSIGTYPE Signal_TERM(int sig)
 {
 #ifdef DEBUG
-   Debug_msg("[%s] Signal handler... (caught SIGNAL: %d) | %s", program_argv0, sig, sys_siglist[sig]);
+   Debug_msg("[%s] Signal handler... (caught SIGNAL: %d) | %s", program_argv0, sig, strsignal(sig));
 #endif
 
-   if (strcmp(program_argv0, PROGRAM)) exit(0);    // is not the main process...
+   if (!strstr(program_argv0, PROGRAM)) exit(0);    // is not the main process...
 
 #ifdef HAVE_NCURSES
    if (!Options.normal)
    {
       char Message[50];
-      sprintf(Message, " Signal handler... (caught SIGNAL: %d) | %s", sig, sys_siglist[sig]);
+      sprintf(Message, " Signal handler... (caught SIGNAL: %d) | %s", sig, strsignal(sig));
       Interface_WExit(Message);
    }
 #else
-   printf("\n Signal handler... (caught SIGNAL: %d) | %s\n\n", sig, sys_siglist[sig]);
+   printf("\n Signal handler... (caught SIGNAL: %d) | %s\n\n", sig, strsignal(sig));
 #endif
    exit(1);
 
 }
 
 
-void Signal_WINCH(int sig)
+RETSIGTYPE Signal_WINCH(int sig)
 {
 
 #ifdef HAVE_NCURSES
@@ -136,7 +140,7 @@ void Signal_WINCH(int sig)
    signal(SIGWINCH, Signal_WINCH);
 }
 
-void Signal_USR1(int sig)
+RETSIGTYPE Signal_USR1(int sig)
 {
    active_dissector = (active_dissector) ? 0 : 1;     // activate/deactivate active dissector (arp based)
    #ifdef DEBUG
@@ -145,7 +149,7 @@ void Signal_USR1(int sig)
    signal(SIGUSR1, Signal_USR1);
 }
 
-void Signal_USR2(int sig)
+RETSIGTYPE Signal_USR2(int sig)
 {
    Connection_Mode = (Connection_Mode) ? 0 : 1;
    #ifdef DEBUG
