@@ -23,9 +23,10 @@
 #include <unistd.h>
 #include <stdlib.h>
 #include <fcntl.h>
-#include <sys/ioctl.h>
+#include <time.h>
 #include <sys/time.h>
 #include <signal.h>
+#include <errno.h>
 
 #include "include/ec_main.h"
 #include "include/ec_error.h"
@@ -38,6 +39,7 @@
 #include "include/ec_buffer.h"
 #include "include/ec_plugins.h"
 #include "include/ec_fingerprint.h"
+#include "include/ec_logtofile.h"
 
 #ifdef DEBUG
    #include "include/ec_debug.h"
@@ -60,6 +62,9 @@
 
 extern char *Execute_Plugin;
 
+char logtofile = 0;
+FILE *logcollect;
+
 // protos...
 #ifdef PERMIT_PLUGINS
    void Simple_Plugin(void);
@@ -69,6 +74,7 @@ void Simple_Run(void);
 void Simple_CheckForPoisoner(void);
 void Simple_FingerPrint(void);
 void Simple_CheckForSwitch(void);
+void Simple_Demonize(void);
 
 //---------------------------------
 
@@ -169,7 +175,7 @@ void Simple_CheckForPoisoner(void)
    if (!found)
       printf("No poisoners found in this lan (seems to be safe)\n\n");
 
-
+   free(SniffList);
 }
 
 #ifdef PERMIT_PLUGINS
@@ -255,6 +261,36 @@ void reset_term()          // taken from readchar.c, by M. Andreoli (2000)
 
 #endif
 
+void Simple_Demonize(void)
+{
+ pid_t pid;
+
+#ifdef DEBUG
+   Debug_msg("Simple_Demonize");
+#endif
+
+   if((signal(SIGTTOU, SIG_IGN)) == SIG_ERR)
+      Error_msg("ec_simple:%d signal() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+
+   if((signal(SIGTTIN, SIG_IGN)) == SIG_ERR)
+      Error_msg("ec_simple:%d signal() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+
+   if((signal(SIGTSTP, SIG_IGN)) == SIG_ERR)
+      Error_msg("ec_simple:%d signal() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+
+   if((signal(SIGHUP, SIG_IGN)) == SIG_ERR)
+      Error_msg("ec_simple:%d signal() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+
+   if((pid = fork()) < 0)
+      Error_msg("ec_simple:%d demonization failed | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+   else if(pid != 0)
+      Error_msg("ettercap demonized with PID: %d", pid);
+
+   if(setsid() == -1)
+      Error_msg("ec_simple:%d setsid() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+
+
+}
 
 
 void Simple_Run(void)
@@ -276,6 +312,7 @@ void Simple_Run(void)
 #ifdef DEBUG
    Debug_msg("Simple_Run - name - [%s][%s]", Host_Dest.name, Host_Source.name);
    Debug_msg("Simple_Run -  IP  - [%s][%s]", Host_Dest.ip, Host_Source.ip);
+   Debug_msg("Simple_Run - port - [%d][%d]", Host_Dest.port, Host_Source.port);
    Debug_msg("Simple_Run -  MAC - [%s][%s]", Host_Dest.mac, Host_Source.mac);
    if (Options.sniff)      Debug_msg("Simple_Run - %c - sniff", proto);
    if (Options.arpsniff)   Debug_msg("Simple_Run - %c - arpsniff", proto);
@@ -285,6 +322,20 @@ void Simple_Run(void)
    if (Options.hexview)
       view = HEX_VIEW;
 
+   if (Options.quiet)
+      Simple_Demonize();
+
+   if (Options.logtofile)
+   {
+      if (Options.collect)
+      {
+         logcollect = LogToFile_open_collect();
+         logtofile = 2;
+      }
+      else
+         logtofile = 1;
+   }
+
    if (strcmp(Host_Source.name, ""))
    {
       strcpy(Host_Source.ip, Inet_NameToIp(Host_Source.name));
@@ -335,7 +386,7 @@ void Simple_Run(void)
 
    // it is ok...
 
-	active_dissector = 0;
+   active_dissector = 0;
 
    if (Options.arpsniff)      // Doppleganger born...
    {
@@ -345,21 +396,21 @@ void Simple_Run(void)
       Dopple_pid = Doppleganger_Run(Options.netiface, Host_Source.ip, Host_Dest.ip, Host_Source.mac, Host_Dest.mac);
    }
 
-   printf("\nPress 'h' for help...\n\n");
+   if (!Options.quiet) printf("\nPress 'h' for help...\n\n");
 
    pipe_with_illithid_data = Buffer_Create(1.0e6); // 1Mb in shared memory !!!
 
 
    if (Options.arpsniff)
    {
-      printf(" Sniffing (ARP based) : %s:%d <--> %s <--> %s:%d\n\n", source, Host_Source.port, Inet_MyIPAddress(), dest, Host_Dest.port);
+      if (!Options.quiet) printf(" Sniffing (ARP based) : %s:%d <--> %s <--> %s:%d\n\n", source, Host_Source.port, Inet_MyIPAddress(), dest, Host_Dest.port);
       if (!Options.collect) Connection_Mode=0;
       Illithid_pid = Illithid_ARPBased_GetConnections(Options.netiface, Host_Source.ip,  Host_Dest.ip, Host_Source.mac, Host_Dest.mac);
       if (!Options.collect) Illithid_pid2 = Illithid_ARPBased_GetData(Options.netiface, proto, Host_Source.ip, Host_Source.port, Host_Dest.ip, Host_Dest.port, Host_Source.mac, Host_Dest.mac);
    }
    else if (Options.sniff)
    {
-      printf(" Sniffing (IP based): %s:%d <--> %s:%d\n\n", source, Host_Source.port, dest, Host_Dest.port );
+      if (!Options.quiet) printf(" Sniffing (IP based): %s:%d <--> %s:%d\n\n", source, Host_Source.port, dest, Host_Dest.port );
       if (!Options.collect) Connection_Mode=0;
       Illithid_pid = Illithid_IPBased_GetConnections(Options.netiface, Host_Source.ip, Host_Dest.ip);
    }
@@ -368,7 +419,7 @@ void Simple_Run(void)
       char check[6];
       Inet_GetMACfromString(Host_Dest.mac, check );   // check for valid mac
       Inet_GetMACfromString(Host_Source.mac, check ); // check for valid mac
-      printf(" Sniffing (MAC based): %s <--> %s\n\n", Host_Dest.mac, Host_Source.mac);
+      if (!Options.quiet) printf(" Sniffing (MAC based): %s <--> %s\n\n", Host_Dest.mac, Host_Source.mac);
       if (!Options.collect) Connection_Mode=0;
       Illithid_pid = Illithid_MACBased_GetConnections(Options.netiface, Host_Dest.mac, Host_Source.mac);
    }
@@ -377,15 +428,18 @@ void Simple_Run(void)
       memset(&TimeOut, 0, sizeof(TimeOut));  //  timeout = 0
       FD_ZERO(&msk_fd);
 
+      if(!Options.quiet)
+      {
 
-#ifdef HAVE_TERMIOS_H
-      set_raw_term();   // non blocking stdin... yes this work !!
-#else
-   #ifdef DEBUG
-      Debug_msg("Simple_Run -- NO TERMIOS_H");
-   #endif
-      fcntl(0, F_SETFL, O_NONBLOCK);   // stdin non blocking... seems to be a non working method for me...
-#endif
+         #ifdef HAVE_TERMIOS_H
+            set_raw_term();   // non blocking stdin... yes this work !!
+         #else
+            #ifdef DEBUG
+               Debug_msg("Simple_Run -- NO TERMIOS_H");
+            #endif
+            fcntl(0, F_SETFL, O_NONBLOCK);   // stdin non blocking... seems to be a non working method for me...
+         #endif
+      }
 
       loop
       {
@@ -418,6 +472,28 @@ void Simple_Run(void)
                      }
                      break;
 
+               case 'L':
+               case 'l':
+                     if (logtofile)
+                     {
+                        printf("\n\nStopping the log to file(s)...\n\n");
+                        if (logtofile == 2) fclose(logcollect);
+                        if (logtofile == 1) LogToFile_close();
+                        logtofile = 0;
+                     }
+                     else
+                     {
+                        printf("\n\nLogging to file(s)...\n\n");
+                        if (!Options.collect)
+                           logtofile = 1;
+                        else
+                        {
+                           logcollect = LogToFile_open_collect();
+                           logtofile = 2;
+                        }
+                     }
+                     break;
+
                case 'S':
                case 's':
                      if (stop == 1)
@@ -440,18 +516,21 @@ void Simple_Run(void)
                         printf(    "[aA]  - dump data in ascii mode\n");
                         printf(    "[xX]  - dump data in hex mode\n");
                      }
+                     printf(    "[lL]  - log all trafic to file(s)\n");
                      printf(    "[sS]  - stop/cont sniffing\n\n");
                      break;
 
                case 'Q':
                case 'q':
 #ifdef HAVE_TERMIOS_H
-                     reset_term();
+                     if(!Options.quiet) reset_term();
 #endif
                      printf("\n\n\nQuitting...\n\n");
                      kill(Illithid_pid, SIGTERM);
+                     if (logtofile == 2) fclose(logcollect);
+                     if (logtofile == 1) LogToFile_close();
                      if (Illithid_pid2) kill(Illithid_pid2,SIGTERM);
-           				if (Dopple_pid) kill(Dopple_pid, SIGTERM);
+                     if (Dopple_pid) kill(Dopple_pid, SIGTERM);
                      exit(0);
                      break;
             }
@@ -465,6 +544,12 @@ void Simple_Run(void)
          if (datalen>0)
          {
 
+            time_t tt;
+            struct tm *dd;
+
+            tt = time(NULL);
+            dd = localtime(&tt);
+
             if (Options.collect)
             {
                int i;
@@ -475,32 +560,55 @@ void Simple_Run(void)
                   if (Conn_Between_Hosts[i].user[0] != 0 &&  Conn_Between_Hosts[i].pass[0] != 0 &&
                       Conn_Between_Hosts[i].user[0] != 1 &&  Conn_Between_Hosts[i].pass[0] != 1 )
                   {
-                     printf("\n\n%s:%d -> %s:%d\t\t%s\n\n",
-                           data_from_illithid_conn.ip_source,
-                           data_from_illithid_conn.source_port,
-                           data_from_illithid_conn.ip_dest,
-                           data_from_illithid_conn.dest_port,
-                           data_from_illithid_conn.type
-                           );
+                     if (logtofile == 2)
+                     {
+                        fprintf(logcollect, "\n\n%02d:%02d:%02d  %s:%d -> %s:%d\t\t%s\n\n", dd->tm_hour, dd->tm_min, dd->tm_sec,
+                                             Conn_Between_Hosts[i].ip_source,
+                                             Conn_Between_Hosts[i].source_port,
+                                             Conn_Between_Hosts[i].ip_dest,
+                                             Conn_Between_Hosts[i].dest_port,
+                                             Conn_Between_Hosts[i].type
+                                             );
 
-                     printf("%s\n", Conn_Between_Hosts[i].user);
-                     printf("%s\n", Conn_Between_Hosts[i].pass);
-                     if (strlen(Conn_Between_Hosts[i].info))
-                        printf("\n%s\n", Conn_Between_Hosts[i].info);
+                        fprintf(logcollect, "%s\n", Conn_Between_Hosts[i].user);
+                        fprintf(logcollect, "%s\n", Conn_Between_Hosts[i].pass);
+                        if (strlen(Conn_Between_Hosts[i].info))
+                           fprintf(logcollect, "\n%s\n", Conn_Between_Hosts[i].info);
+                        fflush(logcollect);
+                     }
+
+                     if (!Options.quiet)
+                     {
+                        printf("\n\n%02d:%02d:%02d  %s:%d -> %s:%d\t\t%s\n\n", dd->tm_hour, dd->tm_min, dd->tm_sec,
+                              Conn_Between_Hosts[i].ip_source,
+                              Conn_Between_Hosts[i].source_port,
+                              Conn_Between_Hosts[i].ip_dest,
+                              Conn_Between_Hosts[i].dest_port,
+                              Conn_Between_Hosts[i].type
+                              );
+
+                        printf("%s\n", Conn_Between_Hosts[i].user);
+                        printf("%s\n", Conn_Between_Hosts[i].pass);
+                        if (strlen(Conn_Between_Hosts[i].info))
+                          printf("\n%s\n", Conn_Between_Hosts[i].info);
+                     }
                      Conn_Between_Hosts[i].user[0] = 1;  // dont display in the future...
                      Conn_Between_Hosts[i].pass[0] = 1;  // dont display in the future...
                   }
                }
+               if (number_of_connections >= 15) Decodedata_RefreshConnectionList(); // periodically refresh the list...
             }
-            else
+            else // !collect
             if (proto == data_from_illithid.proto && Illithid_ToBeSniffed(Host_Source.ip,Host_Source.port,Host_Dest.ip,Host_Dest.port,&data_from_illithid))
             {
 
-               if (!stop )
+               if (logtofile) LogToFile(&data_from_illithid);
+               if (!stop && !Options.quiet )
+               {
                   switch (view)
                   {
                      case ASCII_VIEW:
-                        printf("\n\n\n%s:%d -> %s:%d\n\n%s",
+                        printf("\n\n\n%02d:%02d:%02d  %s:%d -> %s:%d\n\n%s", dd->tm_hour, dd->tm_min, dd->tm_sec,
                            data_from_illithid.ip_source,
                            data_from_illithid.source_port,
                            data_from_illithid.ip_dest,
@@ -511,7 +619,7 @@ void Simple_Run(void)
 
                      case HEX_VIEW:
                         if (data_from_illithid.proto == 'T')
-                           printf("\n\n%s:%d -> %s:%d | seq %lx ack %lx | flags %s |\n%s ",
+                           printf("\n\n%02d:%02d:%02d  %s:%d -> %s:%d | seq %lx ack %lx | flags %s |\n%s ", dd->tm_hour, dd->tm_min, dd->tm_sec,
                               data_from_illithid.ip_source,
                               data_from_illithid.source_port,
                               data_from_illithid.ip_dest,
@@ -522,7 +630,7 @@ void Simple_Run(void)
                               Decodedata_GetHexData(data_from_illithid.data, data_from_illithid.datasize, 80)
                            );
                         else
-                           printf("\n\n%s:%d -> %s:%d | UDP |\n%s ",
+                           printf("\n\n%02d:%02d:%02d  %s:%d -> %s:%d | UDP |\n%s ", dd->tm_hour, dd->tm_min, dd->tm_sec,
                               data_from_illithid.ip_source,
                               data_from_illithid.source_port,
                               data_from_illithid.ip_dest,
@@ -531,7 +639,8 @@ void Simple_Run(void)
                            );
                         break;
                   }
-               fflush(stdout);
+                  fflush(stdout);
+               }
             }
          }
          else
