@@ -2,13 +2,8 @@
    #include <config.h>     // autoheader   -I.
 #endif
 
-#ifdef HAVE_ATEXIT
-   #define exit_func(x)    atexit(x)
-#else
-   #define exit_func(x)
-#endif
-
-#define VERSION "0.4.0"
+#define DEVEL_RELEASE 0
+#define VERSION "0.4.2"
 #define PROGRAM "ettercap"
 #define AUTHORS "ALoR & NaGA"
 
@@ -22,6 +17,17 @@ extern char *program_argv0;
 	#include "../missing/strlcat.h"
 #endif
 
+#ifndef HAVE_MEMMEM					// missing functions
+	#include "../missing/memmem.h"
+#endif
+
+#ifdef HAVE_ATEXIT
+   #define exit_func(x)    atexit(x)
+#else
+   #define exit_func(x)
+#endif
+
+
 typedef struct host_arp          // hosts in LAN info
 {
    int port;
@@ -53,6 +59,8 @@ typedef struct options_list      // arguments passed on command line
    char link:1;
    char collect:1;
    char broadping:1;
+   char logtofile:1;
+   char quiet:1;
    char netiface[10];
    char netmask[16];
 } OPTIONS;
@@ -104,13 +112,27 @@ typedef struct connection        // connection list
 } CONNECTION;
 
 
-typedef struct {                 // buffer structure (ec_buffer.c)
+typedef struct {           // buffer structure (ec_buffer.c)
    short size;
    char *data;
    struct BUFFER *next;
 } BUFFER;
 
 
+#define MAX_INJECT 1000  			// max number of injected chars
+#define MAX_FILTER 200	 			// max filter length
+
+typedef struct {						// filter structure (ec_filterdrop.c)
+	u_char search[MAX_FILTER];
+	short slen;
+	u_char replace[MAX_FILTER];
+	short rlen;
+	char type;
+} DROP_FILTER;
+
+extern DROP_FILTER ARP_Filter_Source;	// ec_filterdrop.c
+extern DROP_FILTER ARP_Filter_Dest;
+
 extern CONNECTION *Conn_Between_Hosts;
 extern int number_of_connections;
 
@@ -118,6 +140,8 @@ extern int pipe_with_illithid;
 extern int pipe_with_illithid_data;
 extern int pipe_inject_stod[2];
 extern int pipe_inject_dtos[2];
+extern int pipe_filter_stod[2];
+extern int pipe_filter_dtos[2];
 
 extern char active_dissector;    // ec_main.c
 extern int Connection_Mode;      // ec_illithid.c
@@ -134,8 +158,6 @@ extern int Connection_Mode;      // ec_illithid.c
    #define TIME_ELAPSED ((finish-start)/CLOCKS_PER_SEC)
 #endif
 
-#define MAX_INJECT 500  // max number of injected char
-
 
 #define ARPBASED  0
 #define PUBLICARP 1
